#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFincoreComplianceRcsmartLivecontentQueryModel(object):

    def __init__(self):
        self._app_name = None
        self._app_token = None
        self._live_audit_time_begain = None
        self._live_audit_time_end = None
        self._live_start_time_begain = None
        self._live_start_time_end = None
        self._page_no = None
        self._page_size = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_token(self):
        return self._app_token

    @app_token.setter
    def app_token(self, value):
        self._app_token = value
    @property
    def live_audit_time_begain(self):
        return self._live_audit_time_begain

    @live_audit_time_begain.setter
    def live_audit_time_begain(self, value):
        self._live_audit_time_begain = value
    @property
    def live_audit_time_end(self):
        return self._live_audit_time_end

    @live_audit_time_end.setter
    def live_audit_time_end(self, value):
        self._live_audit_time_end = value
    @property
    def live_start_time_begain(self):
        return self._live_start_time_begain

    @live_start_time_begain.setter
    def live_start_time_begain(self, value):
        self._live_start_time_begain = value
    @property
    def live_start_time_end(self):
        return self._live_start_time_end

    @live_start_time_end.setter
    def live_start_time_end(self, value):
        self._live_start_time_end = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_token:
            if hasattr(self.app_token, 'to_alipay_dict'):
                params['app_token'] = self.app_token.to_alipay_dict()
            else:
                params['app_token'] = self.app_token
        if self.live_audit_time_begain:
            if hasattr(self.live_audit_time_begain, 'to_alipay_dict'):
                params['live_audit_time_begain'] = self.live_audit_time_begain.to_alipay_dict()
            else:
                params['live_audit_time_begain'] = self.live_audit_time_begain
        if self.live_audit_time_end:
            if hasattr(self.live_audit_time_end, 'to_alipay_dict'):
                params['live_audit_time_end'] = self.live_audit_time_end.to_alipay_dict()
            else:
                params['live_audit_time_end'] = self.live_audit_time_end
        if self.live_start_time_begain:
            if hasattr(self.live_start_time_begain, 'to_alipay_dict'):
                params['live_start_time_begain'] = self.live_start_time_begain.to_alipay_dict()
            else:
                params['live_start_time_begain'] = self.live_start_time_begain
        if self.live_start_time_end:
            if hasattr(self.live_start_time_end, 'to_alipay_dict'):
                params['live_start_time_end'] = self.live_start_time_end.to_alipay_dict()
            else:
                params['live_start_time_end'] = self.live_start_time_end
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFincoreComplianceRcsmartLivecontentQueryModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_token' in d:
            o.app_token = d['app_token']
        if 'live_audit_time_begain' in d:
            o.live_audit_time_begain = d['live_audit_time_begain']
        if 'live_audit_time_end' in d:
            o.live_audit_time_end = d['live_audit_time_end']
        if 'live_start_time_begain' in d:
            o.live_start_time_begain = d['live_start_time_begain']
        if 'live_start_time_end' in d:
            o.live_start_time_end = d['live_start_time_end']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MoreInfoDTO import MoreInfoDTO


class TemplateColumnInfoDTO(object):

    def __init__(self):
        self._code = None
        self._group_title = None
        self._icon_id = None
        self._more_info = None
        self._operate_type = None
        self._tag = None
        self._title = None
        self._value = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def group_title(self):
        return self._group_title

    @group_title.setter
    def group_title(self, value):
        self._group_title = value
    @property
    def icon_id(self):
        return self._icon_id

    @icon_id.setter
    def icon_id(self, value):
        self._icon_id = value
    @property
    def more_info(self):
        return self._more_info

    @more_info.setter
    def more_info(self, value):
        if isinstance(value, MoreInfoDTO):
            self._more_info = value
        else:
            self._more_info = MoreInfoDTO.from_alipay_dict(value)
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value
    @property
    def tag(self):
        return self._tag

    @tag.setter
    def tag(self, value):
        self._tag = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.group_title:
            if hasattr(self.group_title, 'to_alipay_dict'):
                params['group_title'] = self.group_title.to_alipay_dict()
            else:
                params['group_title'] = self.group_title
        if self.icon_id:
            if hasattr(self.icon_id, 'to_alipay_dict'):
                params['icon_id'] = self.icon_id.to_alipay_dict()
            else:
                params['icon_id'] = self.icon_id
        if self.more_info:
            if hasattr(self.more_info, 'to_alipay_dict'):
                params['more_info'] = self.more_info.to_alipay_dict()
            else:
                params['more_info'] = self.more_info
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        if self.tag:
            if hasattr(self.tag, 'to_alipay_dict'):
                params['tag'] = self.tag.to_alipay_dict()
            else:
                params['tag'] = self.tag
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateColumnInfoDTO()
        if 'code' in d:
            o.code = d['code']
        if 'group_title' in d:
            o.group_title = d['group_title']
        if 'icon_id' in d:
            o.icon_id = d['icon_id']
        if 'more_info' in d:
            o.more_info = d['more_info']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        if 'tag' in d:
            o.tag = d['tag']
        if 'title' in d:
            o.title = d['title']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CardInfo import CardInfo
from alipay.aop.api.domain.CodeCouponInfo import CodeCouponInfo
from alipay.aop.api.domain.ConsumeInfo import ConsumeInfo
from alipay.aop.api.domain.ReduceInfo import ReduceInfo


class KoubeiMarketingDataMallDiscountQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingDataMallDiscountQueryResponse, self).__init__()
        self._card_list = None
        self._code_coupon_list = None
        self._consume_list = None
        self._reduce_list = None

    @property
    def card_list(self):
        return self._card_list

    @card_list.setter
    def card_list(self, value):
        if isinstance(value, list):
            self._card_list = list()
            for i in value:
                if isinstance(i, CardInfo):
                    self._card_list.append(i)
                else:
                    self._card_list.append(CardInfo.from_alipay_dict(i))
    @property
    def code_coupon_list(self):
        return self._code_coupon_list

    @code_coupon_list.setter
    def code_coupon_list(self, value):
        if isinstance(value, list):
            self._code_coupon_list = list()
            for i in value:
                if isinstance(i, CodeCouponInfo):
                    self._code_coupon_list.append(i)
                else:
                    self._code_coupon_list.append(CodeCouponInfo.from_alipay_dict(i))
    @property
    def consume_list(self):
        return self._consume_list

    @consume_list.setter
    def consume_list(self, value):
        if isinstance(value, list):
            self._consume_list = list()
            for i in value:
                if isinstance(i, ConsumeInfo):
                    self._consume_list.append(i)
                else:
                    self._consume_list.append(ConsumeInfo.from_alipay_dict(i))
    @property
    def reduce_list(self):
        return self._reduce_list

    @reduce_list.setter
    def reduce_list(self, value):
        if isinstance(value, list):
            self._reduce_list = list()
            for i in value:
                if isinstance(i, ReduceInfo):
                    self._reduce_list.append(i)
                else:
                    self._reduce_list.append(ReduceInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingDataMallDiscountQueryResponse, self).parse_response_content(response_content)
        if 'card_list' in response:
            self.card_list = response['card_list']
        if 'code_coupon_list' in response:
            self.code_coupon_list = response['code_coupon_list']
        if 'consume_list' in response:
            self.consume_list = response['consume_list']
        if 'reduce_list' in response:
            self.reduce_list = response['reduce_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserBenefitEditModel(object):

    def __init__(self):
        self._benefit_area_code = None
        self._benefit_icon_url = None
        self._benefit_id = None
        self._benefit_name = None
        self._benefit_name_as_area_subtitle = None
        self._benefit_page_url = None
        self._benefit_point = None
        self._benefit_rec_biz_id = None
        self._benefit_rec_type = None
        self._benefit_subtitle = None
        self._camp_id = None
        self._eligible_grade = None
        self._end_time = None
        self._exchange_rule_ids = None
        self._grade_discount = None
        self._start_time = None

    @property
    def benefit_area_code(self):
        return self._benefit_area_code

    @benefit_area_code.setter
    def benefit_area_code(self, value):
        self._benefit_area_code = value
    @property
    def benefit_icon_url(self):
        return self._benefit_icon_url

    @benefit_icon_url.setter
    def benefit_icon_url(self, value):
        self._benefit_icon_url = value
    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def benefit_name(self):
        return self._benefit_name

    @benefit_name.setter
    def benefit_name(self, value):
        self._benefit_name = value
    @property
    def benefit_name_as_area_subtitle(self):
        return self._benefit_name_as_area_subtitle

    @benefit_name_as_area_subtitle.setter
    def benefit_name_as_area_subtitle(self, value):
        self._benefit_name_as_area_subtitle = value
    @property
    def benefit_page_url(self):
        return self._benefit_page_url

    @benefit_page_url.setter
    def benefit_page_url(self, value):
        self._benefit_page_url = value
    @property
    def benefit_point(self):
        return self._benefit_point

    @benefit_point.setter
    def benefit_point(self, value):
        self._benefit_point = value
    @property
    def benefit_rec_biz_id(self):
        return self._benefit_rec_biz_id

    @benefit_rec_biz_id.setter
    def benefit_rec_biz_id(self, value):
        self._benefit_rec_biz_id = value
    @property
    def benefit_rec_type(self):
        return self._benefit_rec_type

    @benefit_rec_type.setter
    def benefit_rec_type(self, value):
        self._benefit_rec_type = value
    @property
    def benefit_subtitle(self):
        return self._benefit_subtitle

    @benefit_subtitle.setter
    def benefit_subtitle(self, value):
        self._benefit_subtitle = value
    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def eligible_grade(self):
        return self._eligible_grade

    @eligible_grade.setter
    def eligible_grade(self, value):
        self._eligible_grade = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def exchange_rule_ids(self):
        return self._exchange_rule_ids

    @exchange_rule_ids.setter
    def exchange_rule_ids(self, value):
        self._exchange_rule_ids = value
    @property
    def grade_discount(self):
        return self._grade_discount

    @grade_discount.setter
    def grade_discount(self, value):
        self._grade_discount = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_area_code:
            if hasattr(self.benefit_area_code, 'to_alipay_dict'):
                params['benefit_area_code'] = self.benefit_area_code.to_alipay_dict()
            else:
                params['benefit_area_code'] = self.benefit_area_code
        if self.benefit_icon_url:
            if hasattr(self.benefit_icon_url, 'to_alipay_dict'):
                params['benefit_icon_url'] = self.benefit_icon_url.to_alipay_dict()
            else:
                params['benefit_icon_url'] = self.benefit_icon_url
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.benefit_name:
            if hasattr(self.benefit_name, 'to_alipay_dict'):
                params['benefit_name'] = self.benefit_name.to_alipay_dict()
            else:
                params['benefit_name'] = self.benefit_name
        if self.benefit_name_as_area_subtitle:
            if hasattr(self.benefit_name_as_area_subtitle, 'to_alipay_dict'):
                params['benefit_name_as_area_subtitle'] = self.benefit_name_as_area_subtitle.to_alipay_dict()
            else:
                params['benefit_name_as_area_subtitle'] = self.benefit_name_as_area_subtitle
        if self.benefit_page_url:
            if hasattr(self.benefit_page_url, 'to_alipay_dict'):
                params['benefit_page_url'] = self.benefit_page_url.to_alipay_dict()
            else:
                params['benefit_page_url'] = self.benefit_page_url
        if self.benefit_point:
            if hasattr(self.benefit_point, 'to_alipay_dict'):
                params['benefit_point'] = self.benefit_point.to_alipay_dict()
            else:
                params['benefit_point'] = self.benefit_point
        if self.benefit_rec_biz_id:
            if hasattr(self.benefit_rec_biz_id, 'to_alipay_dict'):
                params['benefit_rec_biz_id'] = self.benefit_rec_biz_id.to_alipay_dict()
            else:
                params['benefit_rec_biz_id'] = self.benefit_rec_biz_id
        if self.benefit_rec_type:
            if hasattr(self.benefit_rec_type, 'to_alipay_dict'):
                params['benefit_rec_type'] = self.benefit_rec_type.to_alipay_dict()
            else:
                params['benefit_rec_type'] = self.benefit_rec_type
        if self.benefit_subtitle:
            if hasattr(self.benefit_subtitle, 'to_alipay_dict'):
                params['benefit_subtitle'] = self.benefit_subtitle.to_alipay_dict()
            else:
                params['benefit_subtitle'] = self.benefit_subtitle
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        if self.eligible_grade:
            if hasattr(self.eligible_grade, 'to_alipay_dict'):
                params['eligible_grade'] = self.eligible_grade.to_alipay_dict()
            else:
                params['eligible_grade'] = self.eligible_grade
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.exchange_rule_ids:
            if hasattr(self.exchange_rule_ids, 'to_alipay_dict'):
                params['exchange_rule_ids'] = self.exchange_rule_ids.to_alipay_dict()
            else:
                params['exchange_rule_ids'] = self.exchange_rule_ids
        if self.grade_discount:
            if hasattr(self.grade_discount, 'to_alipay_dict'):
                params['grade_discount'] = self.grade_discount.to_alipay_dict()
            else:
                params['grade_discount'] = self.grade_discount
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserBenefitEditModel()
        if 'benefit_area_code' in d:
            o.benefit_area_code = d['benefit_area_code']
        if 'benefit_icon_url' in d:
            o.benefit_icon_url = d['benefit_icon_url']
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'benefit_name' in d:
            o.benefit_name = d['benefit_name']
        if 'benefit_name_as_area_subtitle' in d:
            o.benefit_name_as_area_subtitle = d['benefit_name_as_area_subtitle']
        if 'benefit_page_url' in d:
            o.benefit_page_url = d['benefit_page_url']
        if 'benefit_point' in d:
            o.benefit_point = d['benefit_point']
        if 'benefit_rec_biz_id' in d:
            o.benefit_rec_biz_id = d['benefit_rec_biz_id']
        if 'benefit_rec_type' in d:
            o.benefit_rec_type = d['benefit_rec_type']
        if 'benefit_subtitle' in d:
            o.benefit_subtitle = d['benefit_subtitle']
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        if 'eligible_grade' in d:
            o.eligible_grade = d['eligible_grade']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'exchange_rule_ids' in d:
            o.exchange_rule_ids = d['exchange_rule_ids']
        if 'grade_discount' in d:
            o.grade_discount = d['grade_discount']
        if 'start_time' in d:
            o.start_time = d['start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TagRuleItemDTO import TagRuleItemDTO


class TagRuleGroupDTO(object):

    def __init__(self):
        self._rule_items = None

    @property
    def rule_items(self):
        return self._rule_items

    @rule_items.setter
    def rule_items(self, value):
        if isinstance(value, list):
            self._rule_items = list()
            for i in value:
                if isinstance(i, TagRuleItemDTO):
                    self._rule_items.append(i)
                else:
                    self._rule_items.append(TagRuleItemDTO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.rule_items:
            if isinstance(self.rule_items, list):
                for i in range(0, len(self.rule_items)):
                    element = self.rule_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.rule_items[i] = element.to_alipay_dict()
            if hasattr(self.rule_items, 'to_alipay_dict'):
                params['rule_items'] = self.rule_items.to_alipay_dict()
            else:
                params['rule_items'] = self.rule_items
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TagRuleGroupDTO()
        if 'rule_items' in d:
            o.rule_items = d['rule_items']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MemberCardRefundDetail import MemberCardRefundDetail


class AntMerchantExpandMembercardRefundConsultResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandMembercardRefundConsultResponse, self).__init__()
        self._details = None
        self._refund_total_amount = None
        self._refund_total_benefit_amount = None
        self._refund_total_discount_amount = None
        self._refund_total_voucher_amount = None
        self._total_balance = None
        self._total_principal_balance = None

    @property
    def details(self):
        return self._details

    @details.setter
    def details(self, value):
        if isinstance(value, list):
            self._details = list()
            for i in value:
                if isinstance(i, MemberCardRefundDetail):
                    self._details.append(i)
                else:
                    self._details.append(MemberCardRefundDetail.from_alipay_dict(i))
    @property
    def refund_total_amount(self):
        return self._refund_total_amount

    @refund_total_amount.setter
    def refund_total_amount(self, value):
        self._refund_total_amount = value
    @property
    def refund_total_benefit_amount(self):
        return self._refund_total_benefit_amount

    @refund_total_benefit_amount.setter
    def refund_total_benefit_amount(self, value):
        self._refund_total_benefit_amount = value
    @property
    def refund_total_discount_amount(self):
        return self._refund_total_discount_amount

    @refund_total_discount_amount.setter
    def refund_total_discount_amount(self, value):
        self._refund_total_discount_amount = value
    @property
    def refund_total_voucher_amount(self):
        return self._refund_total_voucher_amount

    @refund_total_voucher_amount.setter
    def refund_total_voucher_amount(self, value):
        self._refund_total_voucher_amount = value
    @property
    def total_balance(self):
        return self._total_balance

    @total_balance.setter
    def total_balance(self, value):
        self._total_balance = value
    @property
    def total_principal_balance(self):
        return self._total_principal_balance

    @total_principal_balance.setter
    def total_principal_balance(self, value):
        self._total_principal_balance = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandMembercardRefundConsultResponse, self).parse_response_content(response_content)
        if 'details' in response:
            self.details = response['details']
        if 'refund_total_amount' in response:
            self.refund_total_amount = response['refund_total_amount']
        if 'refund_total_benefit_amount' in response:
            self.refund_total_benefit_amount = response['refund_total_benefit_amount']
        if 'refund_total_discount_amount' in response:
            self.refund_total_discount_amount = response['refund_total_discount_amount']
        if 'refund_total_voucher_amount' in response:
            self.refund_total_voucher_amount = response['refund_total_voucher_amount']
        if 'total_balance' in response:
            self.total_balance = response['total_balance']
        if 'total_principal_balance' in response:
            self.total_principal_balance = response['total_principal_balance']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DeviceTradeInfoList import DeviceTradeInfoList


class AlipayCommerceIotDapplyDevicetradestatlistQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotDapplyDevicetradestatlistQueryResponse, self).__init__()
        self._devicetradestatlist = None
        self._total_count = None

    @property
    def devicetradestatlist(self):
        return self._devicetradestatlist

    @devicetradestatlist.setter
    def devicetradestatlist(self, value):
        if isinstance(value, DeviceTradeInfoList):
            self._devicetradestatlist = value
        else:
            self._devicetradestatlist = DeviceTradeInfoList.from_alipay_dict(value)
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotDapplyDevicetradestatlistQueryResponse, self).parse_response_content(response_content)
        if 'devicetradestatlist' in response:
            self.devicetradestatlist = response['devicetradestatlist']
        if 'total_count' in response:
            self.total_count = response['total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseGroupmemberAddModel(object):

    def __init__(self):
        self._friend_validate = None
        self._group_id = None
        self._open_ids = None
        self._user_ids = None

    @property
    def friend_validate(self):
        return self._friend_validate

    @friend_validate.setter
    def friend_validate(self, value):
        self._friend_validate = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def open_ids(self):
        return self._open_ids

    @open_ids.setter
    def open_ids(self, value):
        if isinstance(value, list):
            self._open_ids = list()
            for i in value:
                self._open_ids.append(i)
    @property
    def user_ids(self):
        return self._user_ids

    @user_ids.setter
    def user_ids(self, value):
        if isinstance(value, list):
            self._user_ids = list()
            for i in value:
                self._user_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.friend_validate:
            if hasattr(self.friend_validate, 'to_alipay_dict'):
                params['friend_validate'] = self.friend_validate.to_alipay_dict()
            else:
                params['friend_validate'] = self.friend_validate
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.open_ids:
            if isinstance(self.open_ids, list):
                for i in range(0, len(self.open_ids)):
                    element = self.open_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.open_ids[i] = element.to_alipay_dict()
            if hasattr(self.open_ids, 'to_alipay_dict'):
                params['open_ids'] = self.open_ids.to_alipay_dict()
            else:
                params['open_ids'] = self.open_ids
        if self.user_ids:
            if isinstance(self.user_ids, list):
                for i in range(0, len(self.user_ids)):
                    element = self.user_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.user_ids[i] = element.to_alipay_dict()
            if hasattr(self.user_ids, 'to_alipay_dict'):
                params['user_ids'] = self.user_ids.to_alipay_dict()
            else:
                params['user_ids'] = self.user_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseGroupmemberAddModel()
        if 'friend_validate' in d:
            o.friend_validate = d['friend_validate']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'open_ids' in d:
            o.open_ids = d['open_ids']
        if 'user_ids' in d:
            o.user_ids = d['user_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpLawsuitRecordGetModel(object):

    def __init__(self):
        self._company_name = None
        self._lawsuit_type = None
        self._org_no = None
        self._product_code = None
        self._transaction_id = None

    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def lawsuit_type(self):
        return self._lawsuit_type

    @lawsuit_type.setter
    def lawsuit_type(self, value):
        self._lawsuit_type = value
    @property
    def org_no(self):
        return self._org_no

    @org_no.setter
    def org_no(self, value):
        self._org_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def transaction_id(self):
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, value):
        self._transaction_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.lawsuit_type:
            if hasattr(self.lawsuit_type, 'to_alipay_dict'):
                params['lawsuit_type'] = self.lawsuit_type.to_alipay_dict()
            else:
                params['lawsuit_type'] = self.lawsuit_type
        if self.org_no:
            if hasattr(self.org_no, 'to_alipay_dict'):
                params['org_no'] = self.org_no.to_alipay_dict()
            else:
                params['org_no'] = self.org_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.transaction_id:
            if hasattr(self.transaction_id, 'to_alipay_dict'):
                params['transaction_id'] = self.transaction_id.to_alipay_dict()
            else:
                params['transaction_id'] = self.transaction_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpLawsuitRecordGetModel()
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'lawsuit_type' in d:
            o.lawsuit_type = d['lawsuit_type']
        if 'org_no' in d:
            o.org_no = d['org_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'transaction_id' in d:
            o.transaction_id = d['transaction_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityRiskAppinfoDetectResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityRiskAppinfoDetectResponse, self).__init__()
        self._app_risk_info_list = None
        self._push = None
        self._request_id = None

    @property
    def app_risk_info_list(self):
        return self._app_risk_info_list

    @app_risk_info_list.setter
    def app_risk_info_list(self, value):
        self._app_risk_info_list = value
    @property
    def push(self):
        return self._push

    @push.setter
    def push(self, value):
        self._push = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityRiskAppinfoDetectResponse, self).parse_response_content(response_content)
        if 'app_risk_info_list' in response:
            self.app_risk_info_list = response['app_risk_info_list']
        if 'push' in response:
            self.push = response['push']
        if 'request_id' in response:
            self.request_id = response['request_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppCommunityOwnercardmsgSyncModel(object):

    def __init__(self):
        self._biz_type = None
        self._city = None
        self._community = None
        self._community_short_name = None
        self._county = None
        self._expired_time = None
        self._id = None
        self._is_top = None
        self._link_url = None
        self._out_id = None
        self._province = None
        self._publish_time = None
        self._publisher = None
        self._service_type = None
        self._status = None
        self._street = None
        self._sub_biz_type = None
        self._template_content = None
        self._template_type = None
        self._title = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def community(self):
        return self._community

    @community.setter
    def community(self, value):
        self._community = value
    @property
    def community_short_name(self):
        return self._community_short_name

    @community_short_name.setter
    def community_short_name(self, value):
        self._community_short_name = value
    @property
    def county(self):
        return self._county

    @county.setter
    def county(self, value):
        self._county = value
    @property
    def expired_time(self):
        return self._expired_time

    @expired_time.setter
    def expired_time(self, value):
        self._expired_time = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def is_top(self):
        return self._is_top

    @is_top.setter
    def is_top(self, value):
        self._is_top = value
    @property
    def link_url(self):
        return self._link_url

    @link_url.setter
    def link_url(self, value):
        self._link_url = value
    @property
    def out_id(self):
        return self._out_id

    @out_id.setter
    def out_id(self, value):
        self._out_id = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def publish_time(self):
        return self._publish_time

    @publish_time.setter
    def publish_time(self, value):
        self._publish_time = value
    @property
    def publisher(self):
        return self._publisher

    @publisher.setter
    def publisher(self, value):
        self._publisher = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def street(self):
        return self._street

    @street.setter
    def street(self, value):
        self._street = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def template_content(self):
        return self._template_content

    @template_content.setter
    def template_content(self, value):
        self._template_content = value
    @property
    def template_type(self):
        return self._template_type

    @template_type.setter
    def template_type(self, value):
        self._template_type = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.community:
            if hasattr(self.community, 'to_alipay_dict'):
                params['community'] = self.community.to_alipay_dict()
            else:
                params['community'] = self.community
        if self.community_short_name:
            if hasattr(self.community_short_name, 'to_alipay_dict'):
                params['community_short_name'] = self.community_short_name.to_alipay_dict()
            else:
                params['community_short_name'] = self.community_short_name
        if self.county:
            if hasattr(self.county, 'to_alipay_dict'):
                params['county'] = self.county.to_alipay_dict()
            else:
                params['county'] = self.county
        if self.expired_time:
            if hasattr(self.expired_time, 'to_alipay_dict'):
                params['expired_time'] = self.expired_time.to_alipay_dict()
            else:
                params['expired_time'] = self.expired_time
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.is_top:
            if hasattr(self.is_top, 'to_alipay_dict'):
                params['is_top'] = self.is_top.to_alipay_dict()
            else:
                params['is_top'] = self.is_top
        if self.link_url:
            if hasattr(self.link_url, 'to_alipay_dict'):
                params['link_url'] = self.link_url.to_alipay_dict()
            else:
                params['link_url'] = self.link_url
        if self.out_id:
            if hasattr(self.out_id, 'to_alipay_dict'):
                params['out_id'] = self.out_id.to_alipay_dict()
            else:
                params['out_id'] = self.out_id
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.publish_time:
            if hasattr(self.publish_time, 'to_alipay_dict'):
                params['publish_time'] = self.publish_time.to_alipay_dict()
            else:
                params['publish_time'] = self.publish_time
        if self.publisher:
            if hasattr(self.publisher, 'to_alipay_dict'):
                params['publisher'] = self.publisher.to_alipay_dict()
            else:
                params['publisher'] = self.publisher
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.street:
            if hasattr(self.street, 'to_alipay_dict'):
                params['street'] = self.street.to_alipay_dict()
            else:
                params['street'] = self.street
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.template_content:
            if hasattr(self.template_content, 'to_alipay_dict'):
                params['template_content'] = self.template_content.to_alipay_dict()
            else:
                params['template_content'] = self.template_content
        if self.template_type:
            if hasattr(self.template_type, 'to_alipay_dict'):
                params['template_type'] = self.template_type.to_alipay_dict()
            else:
                params['template_type'] = self.template_type
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppCommunityOwnercardmsgSyncModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'city' in d:
            o.city = d['city']
        if 'community' in d:
            o.community = d['community']
        if 'community_short_name' in d:
            o.community_short_name = d['community_short_name']
        if 'county' in d:
            o.county = d['county']
        if 'expired_time' in d:
            o.expired_time = d['expired_time']
        if 'id' in d:
            o.id = d['id']
        if 'is_top' in d:
            o.is_top = d['is_top']
        if 'link_url' in d:
            o.link_url = d['link_url']
        if 'out_id' in d:
            o.out_id = d['out_id']
        if 'province' in d:
            o.province = d['province']
        if 'publish_time' in d:
            o.publish_time = d['publish_time']
        if 'publisher' in d:
            o.publisher = d['publisher']
        if 'service_type' in d:
            o.service_type = d['service_type']
        if 'status' in d:
            o.status = d['status']
        if 'street' in d:
            o.street = d['street']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'template_content' in d:
            o.template_content = d['template_content']
        if 'template_type' in d:
            o.template_type = d['template_type']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InteligentItemInfo(object):

    def __init__(self):
        self._item_ids = None
        self._item_imgs = None
        self._item_link = None
        self._item_name = None
        self._item_text = None
        self._max_discount_num = None
        self._min_consume_num = None
        self._original_price = None
        self._sku_min_consume = None
        self._total_max_discount_num = None

    @property
    def item_ids(self):
        return self._item_ids

    @item_ids.setter
    def item_ids(self, value):
        if isinstance(value, list):
            self._item_ids = list()
            for i in value:
                self._item_ids.append(i)
    @property
    def item_imgs(self):
        return self._item_imgs

    @item_imgs.setter
    def item_imgs(self, value):
        if isinstance(value, list):
            self._item_imgs = list()
            for i in value:
                self._item_imgs.append(i)
    @property
    def item_link(self):
        return self._item_link

    @item_link.setter
    def item_link(self, value):
        self._item_link = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def item_text(self):
        return self._item_text

    @item_text.setter
    def item_text(self, value):
        self._item_text = value
    @property
    def max_discount_num(self):
        return self._max_discount_num

    @max_discount_num.setter
    def max_discount_num(self, value):
        self._max_discount_num = value
    @property
    def min_consume_num(self):
        return self._min_consume_num

    @min_consume_num.setter
    def min_consume_num(self, value):
        self._min_consume_num = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def sku_min_consume(self):
        return self._sku_min_consume

    @sku_min_consume.setter
    def sku_min_consume(self, value):
        self._sku_min_consume = value
    @property
    def total_max_discount_num(self):
        return self._total_max_discount_num

    @total_max_discount_num.setter
    def total_max_discount_num(self, value):
        self._total_max_discount_num = value


    def to_alipay_dict(self):
        params = dict()
        if self.item_ids:
            if isinstance(self.item_ids, list):
                for i in range(0, len(self.item_ids)):
                    element = self.item_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_ids[i] = element.to_alipay_dict()
            if hasattr(self.item_ids, 'to_alipay_dict'):
                params['item_ids'] = self.item_ids.to_alipay_dict()
            else:
                params['item_ids'] = self.item_ids
        if self.item_imgs:
            if isinstance(self.item_imgs, list):
                for i in range(0, len(self.item_imgs)):
                    element = self.item_imgs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_imgs[i] = element.to_alipay_dict()
            if hasattr(self.item_imgs, 'to_alipay_dict'):
                params['item_imgs'] = self.item_imgs.to_alipay_dict()
            else:
                params['item_imgs'] = self.item_imgs
        if self.item_link:
            if hasattr(self.item_link, 'to_alipay_dict'):
                params['item_link'] = self.item_link.to_alipay_dict()
            else:
                params['item_link'] = self.item_link
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.item_text:
            if hasattr(self.item_text, 'to_alipay_dict'):
                params['item_text'] = self.item_text.to_alipay_dict()
            else:
                params['item_text'] = self.item_text
        if self.max_discount_num:
            if hasattr(self.max_discount_num, 'to_alipay_dict'):
                params['max_discount_num'] = self.max_discount_num.to_alipay_dict()
            else:
                params['max_discount_num'] = self.max_discount_num
        if self.min_consume_num:
            if hasattr(self.min_consume_num, 'to_alipay_dict'):
                params['min_consume_num'] = self.min_consume_num.to_alipay_dict()
            else:
                params['min_consume_num'] = self.min_consume_num
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.sku_min_consume:
            if hasattr(self.sku_min_consume, 'to_alipay_dict'):
                params['sku_min_consume'] = self.sku_min_consume.to_alipay_dict()
            else:
                params['sku_min_consume'] = self.sku_min_consume
        if self.total_max_discount_num:
            if hasattr(self.total_max_discount_num, 'to_alipay_dict'):
                params['total_max_discount_num'] = self.total_max_discount_num.to_alipay_dict()
            else:
                params['total_max_discount_num'] = self.total_max_discount_num
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InteligentItemInfo()
        if 'item_ids' in d:
            o.item_ids = d['item_ids']
        if 'item_imgs' in d:
            o.item_imgs = d['item_imgs']
        if 'item_link' in d:
            o.item_link = d['item_link']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'item_text' in d:
            o.item_text = d['item_text']
        if 'max_discount_num' in d:
            o.max_discount_num = d['max_discount_num']
        if 'min_consume_num' in d:
            o.min_consume_num = d['min_consume_num']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'sku_min_consume' in d:
            o.sku_min_consume = d['sku_min_consume']
        if 'total_max_discount_num' in d:
            o.total_max_discount_num = d['total_max_discount_num']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingChargeinfoSyncModel(object):

    def __init__(self):
        self._business_hours = None
        self._car_daylight_advanced_price = None
        self._car_daylight_base_price = None
        self._car_night_advanced_price = None
        self._car_night_base_price = None
        self._car_onetime_price = None
        self._daily_price_upperbound = None
        self._daylight_business_hours = None
        self._free_period = None
        self._has_charging_pile = None
        self._is_charge = None
        self._night_business_hours = None
        self._parking_id = None
        self._parking_space_count = None
        self._remark = None
        self._truck_daylight_advanced_price = None
        self._truck_daylight_base_price = None
        self._truck_night_advanced_price = None
        self._truck_night_base_price = None
        self._truck_onetime_price = None

    @property
    def business_hours(self):
        return self._business_hours

    @business_hours.setter
    def business_hours(self, value):
        self._business_hours = value
    @property
    def car_daylight_advanced_price(self):
        return self._car_daylight_advanced_price

    @car_daylight_advanced_price.setter
    def car_daylight_advanced_price(self, value):
        self._car_daylight_advanced_price = value
    @property
    def car_daylight_base_price(self):
        return self._car_daylight_base_price

    @car_daylight_base_price.setter
    def car_daylight_base_price(self, value):
        self._car_daylight_base_price = value
    @property
    def car_night_advanced_price(self):
        return self._car_night_advanced_price

    @car_night_advanced_price.setter
    def car_night_advanced_price(self, value):
        self._car_night_advanced_price = value
    @property
    def car_night_base_price(self):
        return self._car_night_base_price

    @car_night_base_price.setter
    def car_night_base_price(self, value):
        self._car_night_base_price = value
    @property
    def car_onetime_price(self):
        return self._car_onetime_price

    @car_onetime_price.setter
    def car_onetime_price(self, value):
        self._car_onetime_price = value
    @property
    def daily_price_upperbound(self):
        return self._daily_price_upperbound

    @daily_price_upperbound.setter
    def daily_price_upperbound(self, value):
        self._daily_price_upperbound = value
    @property
    def daylight_business_hours(self):
        return self._daylight_business_hours

    @daylight_business_hours.setter
    def daylight_business_hours(self, value):
        self._daylight_business_hours = value
    @property
    def free_period(self):
        return self._free_period

    @free_period.setter
    def free_period(self, value):
        self._free_period = value
    @property
    def has_charging_pile(self):
        return self._has_charging_pile

    @has_charging_pile.setter
    def has_charging_pile(self, value):
        self._has_charging_pile = value
    @property
    def is_charge(self):
        return self._is_charge

    @is_charge.setter
    def is_charge(self, value):
        self._is_charge = value
    @property
    def night_business_hours(self):
        return self._night_business_hours

    @night_business_hours.setter
    def night_business_hours(self, value):
        self._night_business_hours = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value
    @property
    def parking_space_count(self):
        return self._parking_space_count

    @parking_space_count.setter
    def parking_space_count(self, value):
        self._parking_space_count = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def truck_daylight_advanced_price(self):
        return self._truck_daylight_advanced_price

    @truck_daylight_advanced_price.setter
    def truck_daylight_advanced_price(self, value):
        self._truck_daylight_advanced_price = value
    @property
    def truck_daylight_base_price(self):
        return self._truck_daylight_base_price

    @truck_daylight_base_price.setter
    def truck_daylight_base_price(self, value):
        self._truck_daylight_base_price = value
    @property
    def truck_night_advanced_price(self):
        return self._truck_night_advanced_price

    @truck_night_advanced_price.setter
    def truck_night_advanced_price(self, value):
        self._truck_night_advanced_price = value
    @property
    def truck_night_base_price(self):
        return self._truck_night_base_price

    @truck_night_base_price.setter
    def truck_night_base_price(self, value):
        self._truck_night_base_price = value
    @property
    def truck_onetime_price(self):
        return self._truck_onetime_price

    @truck_onetime_price.setter
    def truck_onetime_price(self, value):
        self._truck_onetime_price = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_hours:
            if hasattr(self.business_hours, 'to_alipay_dict'):
                params['business_hours'] = self.business_hours.to_alipay_dict()
            else:
                params['business_hours'] = self.business_hours
        if self.car_daylight_advanced_price:
            if hasattr(self.car_daylight_advanced_price, 'to_alipay_dict'):
                params['car_daylight_advanced_price'] = self.car_daylight_advanced_price.to_alipay_dict()
            else:
                params['car_daylight_advanced_price'] = self.car_daylight_advanced_price
        if self.car_daylight_base_price:
            if hasattr(self.car_daylight_base_price, 'to_alipay_dict'):
                params['car_daylight_base_price'] = self.car_daylight_base_price.to_alipay_dict()
            else:
                params['car_daylight_base_price'] = self.car_daylight_base_price
        if self.car_night_advanced_price:
            if hasattr(self.car_night_advanced_price, 'to_alipay_dict'):
                params['car_night_advanced_price'] = self.car_night_advanced_price.to_alipay_dict()
            else:
                params['car_night_advanced_price'] = self.car_night_advanced_price
        if self.car_night_base_price:
            if hasattr(self.car_night_base_price, 'to_alipay_dict'):
                params['car_night_base_price'] = self.car_night_base_price.to_alipay_dict()
            else:
                params['car_night_base_price'] = self.car_night_base_price
        if self.car_onetime_price:
            if hasattr(self.car_onetime_price, 'to_alipay_dict'):
                params['car_onetime_price'] = self.car_onetime_price.to_alipay_dict()
            else:
                params['car_onetime_price'] = self.car_onetime_price
        if self.daily_price_upperbound:
            if hasattr(self.daily_price_upperbound, 'to_alipay_dict'):
                params['daily_price_upperbound'] = self.daily_price_upperbound.to_alipay_dict()
            else:
                params['daily_price_upperbound'] = self.daily_price_upperbound
        if self.daylight_business_hours:
            if hasattr(self.daylight_business_hours, 'to_alipay_dict'):
                params['daylight_business_hours'] = self.daylight_business_hours.to_alipay_dict()
            else:
                params['daylight_business_hours'] = self.daylight_business_hours
        if self.free_period:
            if hasattr(self.free_period, 'to_alipay_dict'):
                params['free_period'] = self.free_period.to_alipay_dict()
            else:
                params['free_period'] = self.free_period
        if self.has_charging_pile:
            if hasattr(self.has_charging_pile, 'to_alipay_dict'):
                params['has_charging_pile'] = self.has_charging_pile.to_alipay_dict()
            else:
                params['has_charging_pile'] = self.has_charging_pile
        if self.is_charge:
            if hasattr(self.is_charge, 'to_alipay_dict'):
                params['is_charge'] = self.is_charge.to_alipay_dict()
            else:
                params['is_charge'] = self.is_charge
        if self.night_business_hours:
            if hasattr(self.night_business_hours, 'to_alipay_dict'):
                params['night_business_hours'] = self.night_business_hours.to_alipay_dict()
            else:
                params['night_business_hours'] = self.night_business_hours
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        if self.parking_space_count:
            if hasattr(self.parking_space_count, 'to_alipay_dict'):
                params['parking_space_count'] = self.parking_space_count.to_alipay_dict()
            else:
                params['parking_space_count'] = self.parking_space_count
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.truck_daylight_advanced_price:
            if hasattr(self.truck_daylight_advanced_price, 'to_alipay_dict'):
                params['truck_daylight_advanced_price'] = self.truck_daylight_advanced_price.to_alipay_dict()
            else:
                params['truck_daylight_advanced_price'] = self.truck_daylight_advanced_price
        if self.truck_daylight_base_price:
            if hasattr(self.truck_daylight_base_price, 'to_alipay_dict'):
                params['truck_daylight_base_price'] = self.truck_daylight_base_price.to_alipay_dict()
            else:
                params['truck_daylight_base_price'] = self.truck_daylight_base_price
        if self.truck_night_advanced_price:
            if hasattr(self.truck_night_advanced_price, 'to_alipay_dict'):
                params['truck_night_advanced_price'] = self.truck_night_advanced_price.to_alipay_dict()
            else:
                params['truck_night_advanced_price'] = self.truck_night_advanced_price
        if self.truck_night_base_price:
            if hasattr(self.truck_night_base_price, 'to_alipay_dict'):
                params['truck_night_base_price'] = self.truck_night_base_price.to_alipay_dict()
            else:
                params['truck_night_base_price'] = self.truck_night_base_price
        if self.truck_onetime_price:
            if hasattr(self.truck_onetime_price, 'to_alipay_dict'):
                params['truck_onetime_price'] = self.truck_onetime_price.to_alipay_dict()
            else:
                params['truck_onetime_price'] = self.truck_onetime_price
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingChargeinfoSyncModel()
        if 'business_hours' in d:
            o.business_hours = d['business_hours']
        if 'car_daylight_advanced_price' in d:
            o.car_daylight_advanced_price = d['car_daylight_advanced_price']
        if 'car_daylight_base_price' in d:
            o.car_daylight_base_price = d['car_daylight_base_price']
        if 'car_night_advanced_price' in d:
            o.car_night_advanced_price = d['car_night_advanced_price']
        if 'car_night_base_price' in d:
            o.car_night_base_price = d['car_night_base_price']
        if 'car_onetime_price' in d:
            o.car_onetime_price = d['car_onetime_price']
        if 'daily_price_upperbound' in d:
            o.daily_price_upperbound = d['daily_price_upperbound']
        if 'daylight_business_hours' in d:
            o.daylight_business_hours = d['daylight_business_hours']
        if 'free_period' in d:
            o.free_period = d['free_period']
        if 'has_charging_pile' in d:
            o.has_charging_pile = d['has_charging_pile']
        if 'is_charge' in d:
            o.is_charge = d['is_charge']
        if 'night_business_hours' in d:
            o.night_business_hours = d['night_business_hours']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        if 'parking_space_count' in d:
            o.parking_space_count = d['parking_space_count']
        if 'remark' in d:
            o.remark = d['remark']
        if 'truck_daylight_advanced_price' in d:
            o.truck_daylight_advanced_price = d['truck_daylight_advanced_price']
        if 'truck_daylight_base_price' in d:
            o.truck_daylight_base_price = d['truck_daylight_base_price']
        if 'truck_night_advanced_price' in d:
            o.truck_night_advanced_price = d['truck_night_advanced_price']
        if 'truck_night_base_price' in d:
            o.truck_night_base_price = d['truck_night_base_price']
        if 'truck_onetime_price' in d:
            o.truck_onetime_price = d['truck_onetime_price']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenIotbpaasOperationdataUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIotbpaasOperationdataUploadResponse, self).__init__()
        self._flag = None
        self._message = None

    @property
    def flag(self):
        return self._flag

    @flag.setter
    def flag(self, value):
        self._flag = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIotbpaasOperationdataUploadResponse, self).parse_response_content(response_content)
        if 'flag' in response:
            self.flag = response['flag']
        if 'message' in response:
            self.message = response['message']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CrowdBaseInfoDTO import CrowdBaseInfoDTO


class DatadigitalFincloudFinsaasCrowdOdpsCreateModel(object):

    def __init__(self):
        self._crowd_base_info_dto = None
        self._operator_id = None
        self._operator_name = None
        self._organization = None
        self._tenant_code = None

    @property
    def crowd_base_info_dto(self):
        return self._crowd_base_info_dto

    @crowd_base_info_dto.setter
    def crowd_base_info_dto(self, value):
        if isinstance(value, CrowdBaseInfoDTO):
            self._crowd_base_info_dto = value
        else:
            self._crowd_base_info_dto = CrowdBaseInfoDTO.from_alipay_dict(value)
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def operator_name(self):
        return self._operator_name

    @operator_name.setter
    def operator_name(self, value):
        self._operator_name = value
    @property
    def organization(self):
        return self._organization

    @organization.setter
    def organization(self, value):
        self._organization = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.crowd_base_info_dto:
            if hasattr(self.crowd_base_info_dto, 'to_alipay_dict'):
                params['crowd_base_info_dto'] = self.crowd_base_info_dto.to_alipay_dict()
            else:
                params['crowd_base_info_dto'] = self.crowd_base_info_dto
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.operator_name:
            if hasattr(self.operator_name, 'to_alipay_dict'):
                params['operator_name'] = self.operator_name.to_alipay_dict()
            else:
                params['operator_name'] = self.operator_name
        if self.organization:
            if hasattr(self.organization, 'to_alipay_dict'):
                params['organization'] = self.organization.to_alipay_dict()
            else:
                params['organization'] = self.organization
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalFincloudFinsaasCrowdOdpsCreateModel()
        if 'crowd_base_info_dto' in d:
            o.crowd_base_info_dto = d['crowd_base_info_dto']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'operator_name' in d:
            o.operator_name = d['operator_name']
        if 'organization' in d:
            o.organization = d['organization']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchBoxBasicInfoModule(object):

    def __init__(self):
        self._apply_no = None
        self._box_desc = None
        self._fail_reason = None
        self._gmt_modified = None
        self._latest_audit_box_desc = None
        self._module_id = None
        self._module_type = None
        self._status = None

    @property
    def apply_no(self):
        return self._apply_no

    @apply_no.setter
    def apply_no(self, value):
        self._apply_no = value
    @property
    def box_desc(self):
        return self._box_desc

    @box_desc.setter
    def box_desc(self, value):
        self._box_desc = value
    @property
    def fail_reason(self):
        return self._fail_reason

    @fail_reason.setter
    def fail_reason(self, value):
        self._fail_reason = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def latest_audit_box_desc(self):
        return self._latest_audit_box_desc

    @latest_audit_box_desc.setter
    def latest_audit_box_desc(self, value):
        self._latest_audit_box_desc = value
    @property
    def module_id(self):
        return self._module_id

    @module_id.setter
    def module_id(self, value):
        self._module_id = value
    @property
    def module_type(self):
        return self._module_type

    @module_type.setter
    def module_type(self, value):
        self._module_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_no:
            if hasattr(self.apply_no, 'to_alipay_dict'):
                params['apply_no'] = self.apply_no.to_alipay_dict()
            else:
                params['apply_no'] = self.apply_no
        if self.box_desc:
            if hasattr(self.box_desc, 'to_alipay_dict'):
                params['box_desc'] = self.box_desc.to_alipay_dict()
            else:
                params['box_desc'] = self.box_desc
        if self.fail_reason:
            if hasattr(self.fail_reason, 'to_alipay_dict'):
                params['fail_reason'] = self.fail_reason.to_alipay_dict()
            else:
                params['fail_reason'] = self.fail_reason
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.latest_audit_box_desc:
            if hasattr(self.latest_audit_box_desc, 'to_alipay_dict'):
                params['latest_audit_box_desc'] = self.latest_audit_box_desc.to_alipay_dict()
            else:
                params['latest_audit_box_desc'] = self.latest_audit_box_desc
        if self.module_id:
            if hasattr(self.module_id, 'to_alipay_dict'):
                params['module_id'] = self.module_id.to_alipay_dict()
            else:
                params['module_id'] = self.module_id
        if self.module_type:
            if hasattr(self.module_type, 'to_alipay_dict'):
                params['module_type'] = self.module_type.to_alipay_dict()
            else:
                params['module_type'] = self.module_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchBoxBasicInfoModule()
        if 'apply_no' in d:
            o.apply_no = d['apply_no']
        if 'box_desc' in d:
            o.box_desc = d['box_desc']
        if 'fail_reason' in d:
            o.fail_reason = d['fail_reason']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'latest_audit_box_desc' in d:
            o.latest_audit_box_desc = d['latest_audit_box_desc']
        if 'module_id' in d:
            o.module_id = d['module_id']
        if 'module_type' in d:
            o.module_type = d['module_type']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ServiceProductPreviewInfo(object):

    def __init__(self):
        self._id = None
        self._preview_url = None
        self._preview_url_name = None
        self._service_id = None

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def preview_url(self):
        return self._preview_url

    @preview_url.setter
    def preview_url(self, value):
        self._preview_url = value
    @property
    def preview_url_name(self):
        return self._preview_url_name

    @preview_url_name.setter
    def preview_url_name(self, value):
        self._preview_url_name = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.preview_url:
            if hasattr(self.preview_url, 'to_alipay_dict'):
                params['preview_url'] = self.preview_url.to_alipay_dict()
            else:
                params['preview_url'] = self.preview_url
        if self.preview_url_name:
            if hasattr(self.preview_url_name, 'to_alipay_dict'):
                params['preview_url_name'] = self.preview_url_name.to_alipay_dict()
            else:
                params['preview_url_name'] = self.preview_url_name
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ServiceProductPreviewInfo()
        if 'id' in d:
            o.id = d['id']
        if 'preview_url' in d:
            o.preview_url = d['preview_url']
        if 'preview_url_name' in d:
            o.preview_url_name = d['preview_url_name']
        if 'service_id' in d:
            o.service_id = d['service_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditContractBorrowQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditContractBorrowQueryResponse, self).__init__()
        self._status = None
        self._subjects_borrowed = None
        self._subjects_returned = None

    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def subjects_borrowed(self):
        return self._subjects_borrowed

    @subjects_borrowed.setter
    def subjects_borrowed(self, value):
        self._subjects_borrowed = value
    @property
    def subjects_returned(self):
        return self._subjects_returned

    @subjects_returned.setter
    def subjects_returned(self, value):
        self._subjects_returned = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditContractBorrowQueryResponse, self).parse_response_content(response_content)
        if 'status' in response:
            self.status = response['status']
        if 'subjects_borrowed' in response:
            self.subjects_borrowed = response['subjects_borrowed']
        if 'subjects_returned' in response:
            self.subjects_returned = response['subjects_returned']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenSpOperationAuthAddModel(object):

    def __init__(self):
        self._auth_product_code = None
        self._merchant_no = None
        self._out_biz_no = None

    @property
    def auth_product_code(self):
        return self._auth_product_code

    @auth_product_code.setter
    def auth_product_code(self, value):
        self._auth_product_code = value
    @property
    def merchant_no(self):
        return self._merchant_no

    @merchant_no.setter
    def merchant_no(self, value):
        self._merchant_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_product_code:
            if hasattr(self.auth_product_code, 'to_alipay_dict'):
                params['auth_product_code'] = self.auth_product_code.to_alipay_dict()
            else:
                params['auth_product_code'] = self.auth_product_code
        if self.merchant_no:
            if hasattr(self.merchant_no, 'to_alipay_dict'):
                params['merchant_no'] = self.merchant_no.to_alipay_dict()
            else:
                params['merchant_no'] = self.merchant_no
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSpOperationAuthAddModel()
        if 'auth_product_code' in d:
            o.auth_product_code = d['auth_product_code']
        if 'merchant_no' in d:
            o.merchant_no = d['merchant_no']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CardUserInfo import CardUserInfo


class AlipayMarketingCardQueryModel(object):

    def __init__(self):
        self._card_user_info = None
        self._ext_info = None
        self._target_card_no = None
        self._target_card_no_type = None

    @property
    def card_user_info(self):
        return self._card_user_info

    @card_user_info.setter
    def card_user_info(self, value):
        if isinstance(value, CardUserInfo):
            self._card_user_info = value
        else:
            self._card_user_info = CardUserInfo.from_alipay_dict(value)
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def target_card_no(self):
        return self._target_card_no

    @target_card_no.setter
    def target_card_no(self, value):
        self._target_card_no = value
    @property
    def target_card_no_type(self):
        return self._target_card_no_type

    @target_card_no_type.setter
    def target_card_no_type(self, value):
        self._target_card_no_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_user_info:
            if hasattr(self.card_user_info, 'to_alipay_dict'):
                params['card_user_info'] = self.card_user_info.to_alipay_dict()
            else:
                params['card_user_info'] = self.card_user_info
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.target_card_no:
            if hasattr(self.target_card_no, 'to_alipay_dict'):
                params['target_card_no'] = self.target_card_no.to_alipay_dict()
            else:
                params['target_card_no'] = self.target_card_no
        if self.target_card_no_type:
            if hasattr(self.target_card_no_type, 'to_alipay_dict'):
                params['target_card_no_type'] = self.target_card_no_type.to_alipay_dict()
            else:
                params['target_card_no_type'] = self.target_card_no_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCardQueryModel()
        if 'card_user_info' in d:
            o.card_user_info = d['card_user_info']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'target_card_no' in d:
            o.target_card_no = d['target_card_no']
        if 'target_card_no_type' in d:
            o.target_card_no_type = d['target_card_no_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenOperationOpenbizmockPutQueryModel(object):

    def __init__(self):
        self._b_query = None
        self._c_body = None

    @property
    def b_query(self):
        return self._b_query

    @b_query.setter
    def b_query(self, value):
        self._b_query = value
    @property
    def c_body(self):
        return self._c_body

    @c_body.setter
    def c_body(self, value):
        self._c_body = value


    def to_alipay_dict(self):
        params = dict()
        if self.b_query:
            if hasattr(self.b_query, 'to_alipay_dict'):
                params['b_query'] = self.b_query.to_alipay_dict()
            else:
                params['b_query'] = self.b_query
        if self.c_body:
            if hasattr(self.c_body, 'to_alipay_dict'):
                params['c_body'] = self.c_body.to_alipay_dict()
            else:
                params['c_body'] = self.c_body
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenOperationOpenbizmockPutQueryModel()
        if 'b_query' in d:
            o.b_query = d['b_query']
        if 'c_body' in d:
            o.c_body = d['c_body']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AssetResult import AssetResult


class AntMerchantExpandAssetinfoCorrectionSyncResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandAssetinfoCorrectionSyncResponse, self).__init__()
        self._correction_results = None

    @property
    def correction_results(self):
        return self._correction_results

    @correction_results.setter
    def correction_results(self, value):
        if isinstance(value, list):
            self._correction_results = list()
            for i in value:
                if isinstance(i, AssetResult):
                    self._correction_results.append(i)
                else:
                    self._correction_results.append(AssetResult.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandAssetinfoCorrectionSyncResponse, self).parse_response_content(response_content)
        if 'correction_results' in response:
            self.correction_results = response['correction_results']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransBatchCreateorderModel(object):

    def __init__(self):
        self._batch_no = None
        self._ext_param = None
        self._pay_amount = None
        self._payee_id = None
        self._payer_id = None
        self._token = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def payee_id(self):
        return self._payee_id

    @payee_id.setter
    def payee_id(self, value):
        self._payee_id = value
    @property
    def payer_id(self):
        return self._payer_id

    @payer_id.setter
    def payer_id(self, value):
        self._payer_id = value
    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, value):
        self._token = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.payee_id:
            if hasattr(self.payee_id, 'to_alipay_dict'):
                params['payee_id'] = self.payee_id.to_alipay_dict()
            else:
                params['payee_id'] = self.payee_id
        if self.payer_id:
            if hasattr(self.payer_id, 'to_alipay_dict'):
                params['payer_id'] = self.payer_id.to_alipay_dict()
            else:
                params['payer_id'] = self.payer_id
        if self.token:
            if hasattr(self.token, 'to_alipay_dict'):
                params['token'] = self.token.to_alipay_dict()
            else:
                params['token'] = self.token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransBatchCreateorderModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'payee_id' in d:
            o.payee_id = d['payee_id']
        if 'payer_id' in d:
            o.payer_id = d['payer_id']
        if 'token' in d:
            o.token = d['token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdFingerprintApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdFingerprintApplyResponse, self).__init__()
        self._auth_type = None
        self._device_id = None
        self._token = None

    @property
    def auth_type(self):
        return self._auth_type

    @auth_type.setter
    def auth_type(self, value):
        self._auth_type = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, value):
        self._token = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdFingerprintApplyResponse, self).parse_response_content(response_content)
        if 'auth_type' in response:
            self.auth_type = response['auth_type']
        if 'device_id' in response:
            self.device_id = response['device_id']
        if 'token' in response:
            self.token = response['token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCcmSwTreeGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCcmSwTreeGetResponse, self).__init__()
        self._tree = None

    @property
    def tree(self):
        return self._tree

    @tree.setter
    def tree(self, value):
        self._tree = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCcmSwTreeGetResponse, self).parse_response_content(response_content)
        if 'tree' in response:
            self.tree = response['tree']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingVoucherStockMatchResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherStockMatchResponse, self).__init__()
        self._exist_list = None
        self._not_exist_list = None

    @property
    def exist_list(self):
        return self._exist_list

    @exist_list.setter
    def exist_list(self, value):
        if isinstance(value, list):
            self._exist_list = list()
            for i in value:
                self._exist_list.append(i)
    @property
    def not_exist_list(self):
        return self._not_exist_list

    @not_exist_list.setter
    def not_exist_list(self, value):
        if isinstance(value, list):
            self._not_exist_list = list()
            for i in value:
                self._not_exist_list.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherStockMatchResponse, self).parse_response_content(response_content)
        if 'exist_list' in response:
            self.exist_list = response['exist_list']
        if 'not_exist_list' in response:
            self.not_exist_list = response['not_exist_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InboundOrder import InboundOrder
from alipay.aop.api.domain.OperateContext import OperateContext
from alipay.aop.api.domain.InboundOrderLine import InboundOrderLine


class KoubeiRetailWmsInboundorderCreateModel(object):

    def __init__(self):
        self._inbound_order = None
        self._operate_context = None
        self._order_lines = None

    @property
    def inbound_order(self):
        return self._inbound_order

    @inbound_order.setter
    def inbound_order(self, value):
        if isinstance(value, InboundOrder):
            self._inbound_order = value
        else:
            self._inbound_order = InboundOrder.from_alipay_dict(value)
    @property
    def operate_context(self):
        return self._operate_context

    @operate_context.setter
    def operate_context(self, value):
        if isinstance(value, OperateContext):
            self._operate_context = value
        else:
            self._operate_context = OperateContext.from_alipay_dict(value)
    @property
    def order_lines(self):
        return self._order_lines

    @order_lines.setter
    def order_lines(self, value):
        if isinstance(value, list):
            self._order_lines = list()
            for i in value:
                if isinstance(i, InboundOrderLine):
                    self._order_lines.append(i)
                else:
                    self._order_lines.append(InboundOrderLine.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.inbound_order:
            if hasattr(self.inbound_order, 'to_alipay_dict'):
                params['inbound_order'] = self.inbound_order.to_alipay_dict()
            else:
                params['inbound_order'] = self.inbound_order
        if self.operate_context:
            if hasattr(self.operate_context, 'to_alipay_dict'):
                params['operate_context'] = self.operate_context.to_alipay_dict()
            else:
                params['operate_context'] = self.operate_context
        if self.order_lines:
            if isinstance(self.order_lines, list):
                for i in range(0, len(self.order_lines)):
                    element = self.order_lines[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_lines[i] = element.to_alipay_dict()
            if hasattr(self.order_lines, 'to_alipay_dict'):
                params['order_lines'] = self.order_lines.to_alipay_dict()
            else:
                params['order_lines'] = self.order_lines
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiRetailWmsInboundorderCreateModel()
        if 'inbound_order' in d:
            o.inbound_order = d['inbound_order']
        if 'operate_context' in d:
            o.operate_context = d['operate_context']
        if 'order_lines' in d:
            o.order_lines = d['order_lines']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsPos(object):

    def __init__(self):
        self._goods_id = None
        self._pos = None

    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def pos(self):
        return self._pos

    @pos.setter
    def pos(self, value):
        self._pos = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.pos:
            if hasattr(self.pos, 'to_alipay_dict'):
                params['pos'] = self.pos.to_alipay_dict()
            else:
                params['pos'] = self.pos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsPos()
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'pos' in d:
            o.pos = d['pos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceMerchantEnterstatusQueryModel(object):

    def __init__(self):
        self._m_short_name = None
        self._process_id = None
        self._product_code = None

    @property
    def m_short_name(self):
        return self._m_short_name

    @m_short_name.setter
    def m_short_name(self, value):
        self._m_short_name = value
    @property
    def process_id(self):
        return self._process_id

    @process_id.setter
    def process_id(self, value):
        self._process_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.m_short_name:
            if hasattr(self.m_short_name, 'to_alipay_dict'):
                params['m_short_name'] = self.m_short_name.to_alipay_dict()
            else:
                params['m_short_name'] = self.m_short_name
        if self.process_id:
            if hasattr(self.process_id, 'to_alipay_dict'):
                params['process_id'] = self.process_id.to_alipay_dict()
            else:
                params['process_id'] = self.process_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceMerchantEnterstatusQueryModel()
        if 'm_short_name' in d:
            o.m_short_name = d['m_short_name']
        if 'process_id' in d:
            o.process_id = d['process_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TimeRestrictInfo import TimeRestrictInfo


class VoucherAbsolutePeriodInfo(object):

    def __init__(self):
        self._time_restrict_info = None
        self._valid_begin_time = None
        self._valid_end_time = None

    @property
    def time_restrict_info(self):
        return self._time_restrict_info

    @time_restrict_info.setter
    def time_restrict_info(self, value):
        if isinstance(value, TimeRestrictInfo):
            self._time_restrict_info = value
        else:
            self._time_restrict_info = TimeRestrictInfo.from_alipay_dict(value)
    @property
    def valid_begin_time(self):
        return self._valid_begin_time

    @valid_begin_time.setter
    def valid_begin_time(self, value):
        self._valid_begin_time = value
    @property
    def valid_end_time(self):
        return self._valid_end_time

    @valid_end_time.setter
    def valid_end_time(self, value):
        self._valid_end_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.time_restrict_info:
            if hasattr(self.time_restrict_info, 'to_alipay_dict'):
                params['time_restrict_info'] = self.time_restrict_info.to_alipay_dict()
            else:
                params['time_restrict_info'] = self.time_restrict_info
        if self.valid_begin_time:
            if hasattr(self.valid_begin_time, 'to_alipay_dict'):
                params['valid_begin_time'] = self.valid_begin_time.to_alipay_dict()
            else:
                params['valid_begin_time'] = self.valid_begin_time
        if self.valid_end_time:
            if hasattr(self.valid_end_time, 'to_alipay_dict'):
                params['valid_end_time'] = self.valid_end_time.to_alipay_dict()
            else:
                params['valid_end_time'] = self.valid_end_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherAbsolutePeriodInfo()
        if 'time_restrict_info' in d:
            o.time_restrict_info = d['time_restrict_info']
        if 'valid_begin_time' in d:
            o.valid_begin_time = d['valid_begin_time']
        if 'valid_end_time' in d:
            o.valid_end_time = d['valid_end_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherAvailableGeographyAllShopInfo import VoucherAvailableGeographyAllShopInfo


class VoucherAvailableGeographyShopInfo(object):

    def __init__(self):
        self._available_geography_all_shop = None
        self._available_real_shop_ids = None
        self._available_shop_ids = None

    @property
    def available_geography_all_shop(self):
        return self._available_geography_all_shop

    @available_geography_all_shop.setter
    def available_geography_all_shop(self, value):
        if isinstance(value, VoucherAvailableGeographyAllShopInfo):
            self._available_geography_all_shop = value
        else:
            self._available_geography_all_shop = VoucherAvailableGeographyAllShopInfo.from_alipay_dict(value)
    @property
    def available_real_shop_ids(self):
        return self._available_real_shop_ids

    @available_real_shop_ids.setter
    def available_real_shop_ids(self, value):
        if isinstance(value, list):
            self._available_real_shop_ids = list()
            for i in value:
                self._available_real_shop_ids.append(i)
    @property
    def available_shop_ids(self):
        return self._available_shop_ids

    @available_shop_ids.setter
    def available_shop_ids(self, value):
        if isinstance(value, list):
            self._available_shop_ids = list()
            for i in value:
                self._available_shop_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.available_geography_all_shop:
            if hasattr(self.available_geography_all_shop, 'to_alipay_dict'):
                params['available_geography_all_shop'] = self.available_geography_all_shop.to_alipay_dict()
            else:
                params['available_geography_all_shop'] = self.available_geography_all_shop
        if self.available_real_shop_ids:
            if isinstance(self.available_real_shop_ids, list):
                for i in range(0, len(self.available_real_shop_ids)):
                    element = self.available_real_shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_real_shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.available_real_shop_ids, 'to_alipay_dict'):
                params['available_real_shop_ids'] = self.available_real_shop_ids.to_alipay_dict()
            else:
                params['available_real_shop_ids'] = self.available_real_shop_ids
        if self.available_shop_ids:
            if isinstance(self.available_shop_ids, list):
                for i in range(0, len(self.available_shop_ids)):
                    element = self.available_shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.available_shop_ids, 'to_alipay_dict'):
                params['available_shop_ids'] = self.available_shop_ids.to_alipay_dict()
            else:
                params['available_shop_ids'] = self.available_shop_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherAvailableGeographyShopInfo()
        if 'available_geography_all_shop' in d:
            o.available_geography_all_shop = d['available_geography_all_shop']
        if 'available_real_shop_ids' in d:
            o.available_real_shop_ids = d['available_real_shop_ids']
        if 'available_shop_ids' in d:
            o.available_shop_ids = d['available_shop_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenIpsponsorConsumegoldQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIpsponsorConsumegoldQueryResponse, self).__init__()
        self._open_status = None
        self._total_amount = None

    @property
    def open_status(self):
        return self._open_status

    @open_status.setter
    def open_status(self, value):
        self._open_status = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIpsponsorConsumegoldQueryResponse, self).parse_response_content(response_content)
        if 'open_status' in response:
            self.open_status = response['open_status']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IdentityDTO(object):

    def __init__(self):
        self._agent = None
        self._agent_id = None
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._legal_person = None
        self._legal_person_id = None
        self._mobile_no = None
        self._user_type = None

    @property
    def agent(self):
        return self._agent

    @agent.setter
    def agent(self, value):
        self._agent = value
    @property
    def agent_id(self):
        return self._agent_id

    @agent_id.setter
    def agent_id(self, value):
        self._agent_id = value
    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def legal_person(self):
        return self._legal_person

    @legal_person.setter
    def legal_person(self, value):
        self._legal_person = value
    @property
    def legal_person_id(self):
        return self._legal_person_id

    @legal_person_id.setter
    def legal_person_id(self, value):
        self._legal_person_id = value
    @property
    def mobile_no(self):
        return self._mobile_no

    @mobile_no.setter
    def mobile_no(self, value):
        self._mobile_no = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent:
            if hasattr(self.agent, 'to_alipay_dict'):
                params['agent'] = self.agent.to_alipay_dict()
            else:
                params['agent'] = self.agent
        if self.agent_id:
            if hasattr(self.agent_id, 'to_alipay_dict'):
                params['agent_id'] = self.agent_id.to_alipay_dict()
            else:
                params['agent_id'] = self.agent_id
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.legal_person:
            if hasattr(self.legal_person, 'to_alipay_dict'):
                params['legal_person'] = self.legal_person.to_alipay_dict()
            else:
                params['legal_person'] = self.legal_person
        if self.legal_person_id:
            if hasattr(self.legal_person_id, 'to_alipay_dict'):
                params['legal_person_id'] = self.legal_person_id.to_alipay_dict()
            else:
                params['legal_person_id'] = self.legal_person_id
        if self.mobile_no:
            if hasattr(self.mobile_no, 'to_alipay_dict'):
                params['mobile_no'] = self.mobile_no.to_alipay_dict()
            else:
                params['mobile_no'] = self.mobile_no
        if self.user_type:
            if hasattr(self.user_type, 'to_alipay_dict'):
                params['user_type'] = self.user_type.to_alipay_dict()
            else:
                params['user_type'] = self.user_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IdentityDTO()
        if 'agent' in d:
            o.agent = d['agent']
        if 'agent_id' in d:
            o.agent_id = d['agent_id']
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'legal_person' in d:
            o.legal_person = d['legal_person']
        if 'legal_person_id' in d:
            o.legal_person_id = d['legal_person_id']
        if 'mobile_no' in d:
            o.mobile_no = d['mobile_no']
        if 'user_type' in d:
            o.user_type = d['user_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FundAccountBookInfo(object):

    def __init__(self):
        self._account_book_id = None
        self._available_amount = None
        self._card_no = None
        self._type = None

    @property
    def account_book_id(self):
        return self._account_book_id

    @account_book_id.setter
    def account_book_id(self, value):
        self._account_book_id = value
    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        self._available_amount = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_book_id:
            if hasattr(self.account_book_id, 'to_alipay_dict'):
                params['account_book_id'] = self.account_book_id.to_alipay_dict()
            else:
                params['account_book_id'] = self.account_book_id
        if self.available_amount:
            if hasattr(self.available_amount, 'to_alipay_dict'):
                params['available_amount'] = self.available_amount.to_alipay_dict()
            else:
                params['available_amount'] = self.available_amount
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FundAccountBookInfo()
        if 'account_book_id' in d:
            o.account_book_id = d['account_book_id']
        if 'available_amount' in d:
            o.available_amount = d['available_amount']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.NimitzColumn import NimitzColumn


class NimitzTable(object):

    def __init__(self):
        self._columns = None

    @property
    def columns(self):
        return self._columns

    @columns.setter
    def columns(self, value):
        if isinstance(value, list):
            self._columns = list()
            for i in value:
                if isinstance(i, NimitzColumn):
                    self._columns.append(i)
                else:
                    self._columns.append(NimitzColumn.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.columns:
            if isinstance(self.columns, list):
                for i in range(0, len(self.columns)):
                    element = self.columns[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.columns[i] = element.to_alipay_dict()
            if hasattr(self.columns, 'to_alipay_dict'):
                params['columns'] = self.columns.to_alipay_dict()
            else:
                params['columns'] = self.columns
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NimitzTable()
        if 'columns' in d:
            o.columns = d['columns']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class DatadigitalFincloudGeneralsaasFaceSourceCertifyResponse(AlipayResponse):

    def __init__(self):
        super(DatadigitalFincloudGeneralsaasFaceSourceCertifyResponse, self).__init__()
        self._certify_no = None
        self._mismatch_reason = None
        self._passed = None
        self._quality = None
        self._score = None

    @property
    def certify_no(self):
        return self._certify_no

    @certify_no.setter
    def certify_no(self, value):
        self._certify_no = value
    @property
    def mismatch_reason(self):
        return self._mismatch_reason

    @mismatch_reason.setter
    def mismatch_reason(self, value):
        self._mismatch_reason = value
    @property
    def passed(self):
        return self._passed

    @passed.setter
    def passed(self, value):
        self._passed = value
    @property
    def quality(self):
        return self._quality

    @quality.setter
    def quality(self, value):
        self._quality = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value

    def parse_response_content(self, response_content):
        response = super(DatadigitalFincloudGeneralsaasFaceSourceCertifyResponse, self).parse_response_content(response_content)
        if 'certify_no' in response:
            self.certify_no = response['certify_no']
        if 'mismatch_reason' in response:
            self.mismatch_reason = response['mismatch_reason']
        if 'passed' in response:
            self.passed = response['passed']
        if 'quality' in response:
            self.quality = response['quality']
        if 'score' in response:
            self.score = response['score']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TaskMaterialInfo(object):

    def __init__(self):
        self._button_text_award = None
        self._button_text_done = None
        self._button_text_signup = None
        self._icon = None
        self._link = None
        self._sub_title = None
        self._title = None

    @property
    def button_text_award(self):
        return self._button_text_award

    @button_text_award.setter
    def button_text_award(self, value):
        self._button_text_award = value
    @property
    def button_text_done(self):
        return self._button_text_done

    @button_text_done.setter
    def button_text_done(self, value):
        self._button_text_done = value
    @property
    def button_text_signup(self):
        return self._button_text_signup

    @button_text_signup.setter
    def button_text_signup(self, value):
        self._button_text_signup = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def link(self):
        return self._link

    @link.setter
    def link(self, value):
        self._link = value
    @property
    def sub_title(self):
        return self._sub_title

    @sub_title.setter
    def sub_title(self, value):
        self._sub_title = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.button_text_award:
            if hasattr(self.button_text_award, 'to_alipay_dict'):
                params['button_text_award'] = self.button_text_award.to_alipay_dict()
            else:
                params['button_text_award'] = self.button_text_award
        if self.button_text_done:
            if hasattr(self.button_text_done, 'to_alipay_dict'):
                params['button_text_done'] = self.button_text_done.to_alipay_dict()
            else:
                params['button_text_done'] = self.button_text_done
        if self.button_text_signup:
            if hasattr(self.button_text_signup, 'to_alipay_dict'):
                params['button_text_signup'] = self.button_text_signup.to_alipay_dict()
            else:
                params['button_text_signup'] = self.button_text_signup
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.link:
            if hasattr(self.link, 'to_alipay_dict'):
                params['link'] = self.link.to_alipay_dict()
            else:
                params['link'] = self.link
        if self.sub_title:
            if hasattr(self.sub_title, 'to_alipay_dict'):
                params['sub_title'] = self.sub_title.to_alipay_dict()
            else:
                params['sub_title'] = self.sub_title
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TaskMaterialInfo()
        if 'button_text_award' in d:
            o.button_text_award = d['button_text_award']
        if 'button_text_done' in d:
            o.button_text_done = d['button_text_done']
        if 'button_text_signup' in d:
            o.button_text_signup = d['button_text_signup']
        if 'icon' in d:
            o.icon = d['icon']
        if 'link' in d:
            o.link = d['link']
        if 'sub_title' in d:
            o.sub_title = d['sub_title']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoContractProcessDeleteModel(object):

    def __init__(self):
        self._batch_no = None
        self._flow_ids = None
        self._sign_platform_code = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def flow_ids(self):
        return self._flow_ids

    @flow_ids.setter
    def flow_ids(self, value):
        if isinstance(value, list):
            self._flow_ids = list()
            for i in value:
                self._flow_ids.append(i)
    @property
    def sign_platform_code(self):
        return self._sign_platform_code

    @sign_platform_code.setter
    def sign_platform_code(self, value):
        self._sign_platform_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.flow_ids:
            if isinstance(self.flow_ids, list):
                for i in range(0, len(self.flow_ids)):
                    element = self.flow_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.flow_ids[i] = element.to_alipay_dict()
            if hasattr(self.flow_ids, 'to_alipay_dict'):
                params['flow_ids'] = self.flow_ids.to_alipay_dict()
            else:
                params['flow_ids'] = self.flow_ids
        if self.sign_platform_code:
            if hasattr(self.sign_platform_code, 'to_alipay_dict'):
                params['sign_platform_code'] = self.sign_platform_code.to_alipay_dict()
            else:
                params['sign_platform_code'] = self.sign_platform_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoContractProcessDeleteModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'flow_ids' in d:
            o.flow_ids = d['flow_ids']
        if 'sign_platform_code' in d:
            o.sign_platform_code = d['sign_platform_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CrowdSelectTagValuesOpenRequest import CrowdSelectTagValuesOpenRequest


class CrowdSelectTagOpenRequest(object):

    def __init__(self):
        self._select_tag_values = None

    @property
    def select_tag_values(self):
        return self._select_tag_values

    @select_tag_values.setter
    def select_tag_values(self, value):
        if isinstance(value, list):
            self._select_tag_values = list()
            for i in value:
                if isinstance(i, CrowdSelectTagValuesOpenRequest):
                    self._select_tag_values.append(i)
                else:
                    self._select_tag_values.append(CrowdSelectTagValuesOpenRequest.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.select_tag_values:
            if isinstance(self.select_tag_values, list):
                for i in range(0, len(self.select_tag_values)):
                    element = self.select_tag_values[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.select_tag_values[i] = element.to_alipay_dict()
            if hasattr(self.select_tag_values, 'to_alipay_dict'):
                params['select_tag_values'] = self.select_tag_values.to_alipay_dict()
            else:
                params['select_tag_values'] = self.select_tag_values
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CrowdSelectTagOpenRequest()
        if 'select_tag_values' in d:
            o.select_tag_values = d['select_tag_values']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseMcommentFootprintSendModel(object):

    def __init__(self):
        self._biz_type = None
        self._ext_data = None
        self._footprint_model_code = None
        self._footprint_model_data = None
        self._footprint_time = None
        self._item_id = None
        self._open_id = None
        self._source = None
        self._user_id = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def ext_data(self):
        return self._ext_data

    @ext_data.setter
    def ext_data(self, value):
        self._ext_data = value
    @property
    def footprint_model_code(self):
        return self._footprint_model_code

    @footprint_model_code.setter
    def footprint_model_code(self, value):
        self._footprint_model_code = value
    @property
    def footprint_model_data(self):
        return self._footprint_model_data

    @footprint_model_data.setter
    def footprint_model_data(self, value):
        self._footprint_model_data = value
    @property
    def footprint_time(self):
        return self._footprint_time

    @footprint_time.setter
    def footprint_time(self, value):
        self._footprint_time = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.ext_data:
            if hasattr(self.ext_data, 'to_alipay_dict'):
                params['ext_data'] = self.ext_data.to_alipay_dict()
            else:
                params['ext_data'] = self.ext_data
        if self.footprint_model_code:
            if hasattr(self.footprint_model_code, 'to_alipay_dict'):
                params['footprint_model_code'] = self.footprint_model_code.to_alipay_dict()
            else:
                params['footprint_model_code'] = self.footprint_model_code
        if self.footprint_model_data:
            if hasattr(self.footprint_model_data, 'to_alipay_dict'):
                params['footprint_model_data'] = self.footprint_model_data.to_alipay_dict()
            else:
                params['footprint_model_data'] = self.footprint_model_data
        if self.footprint_time:
            if hasattr(self.footprint_time, 'to_alipay_dict'):
                params['footprint_time'] = self.footprint_time.to_alipay_dict()
            else:
                params['footprint_time'] = self.footprint_time
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseMcommentFootprintSendModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'ext_data' in d:
            o.ext_data = d['ext_data']
        if 'footprint_model_code' in d:
            o.footprint_model_code = d['footprint_model_code']
        if 'footprint_model_data' in d:
            o.footprint_model_data = d['footprint_model_data']
        if 'footprint_time' in d:
            o.footprint_time = d['footprint_time']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'source' in d:
            o.source = d['source']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CardQuickServiceDTO import CardQuickServiceDTO


class CardLevelConfigDTO(object):

    def __init__(self):
        self._background_url = None
        self._banner_image_url = None
        self._banner_url = None
        self._level = None
        self._logo_url = None
        self._quick_services = None
        self._sub_title = None
        self._title = None

    @property
    def background_url(self):
        return self._background_url

    @background_url.setter
    def background_url(self, value):
        self._background_url = value
    @property
    def banner_image_url(self):
        return self._banner_image_url

    @banner_image_url.setter
    def banner_image_url(self, value):
        self._banner_image_url = value
    @property
    def banner_url(self):
        return self._banner_url

    @banner_url.setter
    def banner_url(self, value):
        self._banner_url = value
    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def logo_url(self):
        return self._logo_url

    @logo_url.setter
    def logo_url(self, value):
        self._logo_url = value
    @property
    def quick_services(self):
        return self._quick_services

    @quick_services.setter
    def quick_services(self, value):
        if isinstance(value, list):
            self._quick_services = list()
            for i in value:
                if isinstance(i, CardQuickServiceDTO):
                    self._quick_services.append(i)
                else:
                    self._quick_services.append(CardQuickServiceDTO.from_alipay_dict(i))
    @property
    def sub_title(self):
        return self._sub_title

    @sub_title.setter
    def sub_title(self, value):
        self._sub_title = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.background_url:
            if hasattr(self.background_url, 'to_alipay_dict'):
                params['background_url'] = self.background_url.to_alipay_dict()
            else:
                params['background_url'] = self.background_url
        if self.banner_image_url:
            if hasattr(self.banner_image_url, 'to_alipay_dict'):
                params['banner_image_url'] = self.banner_image_url.to_alipay_dict()
            else:
                params['banner_image_url'] = self.banner_image_url
        if self.banner_url:
            if hasattr(self.banner_url, 'to_alipay_dict'):
                params['banner_url'] = self.banner_url.to_alipay_dict()
            else:
                params['banner_url'] = self.banner_url
        if self.level:
            if hasattr(self.level, 'to_alipay_dict'):
                params['level'] = self.level.to_alipay_dict()
            else:
                params['level'] = self.level
        if self.logo_url:
            if hasattr(self.logo_url, 'to_alipay_dict'):
                params['logo_url'] = self.logo_url.to_alipay_dict()
            else:
                params['logo_url'] = self.logo_url
        if self.quick_services:
            if isinstance(self.quick_services, list):
                for i in range(0, len(self.quick_services)):
                    element = self.quick_services[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.quick_services[i] = element.to_alipay_dict()
            if hasattr(self.quick_services, 'to_alipay_dict'):
                params['quick_services'] = self.quick_services.to_alipay_dict()
            else:
                params['quick_services'] = self.quick_services
        if self.sub_title:
            if hasattr(self.sub_title, 'to_alipay_dict'):
                params['sub_title'] = self.sub_title.to_alipay_dict()
            else:
                params['sub_title'] = self.sub_title
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CardLevelConfigDTO()
        if 'background_url' in d:
            o.background_url = d['background_url']
        if 'banner_image_url' in d:
            o.banner_image_url = d['banner_image_url']
        if 'banner_url' in d:
            o.banner_url = d['banner_url']
        if 'level' in d:
            o.level = d['level']
        if 'logo_url' in d:
            o.logo_url = d['logo_url']
        if 'quick_services' in d:
            o.quick_services = d['quick_services']
        if 'sub_title' in d:
            o.sub_title = d['sub_title']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppCommunityCommunityinfoCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppCommunityCommunityinfoCreateResponse, self).__init__()
        self._community_short_name = None
        self._community_url = None

    @property
    def community_short_name(self):
        return self._community_short_name

    @community_short_name.setter
    def community_short_name(self, value):
        self._community_short_name = value
    @property
    def community_url(self):
        return self._community_url

    @community_url.setter
    def community_url(self, value):
        self._community_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppCommunityCommunityinfoCreateResponse, self).parse_response_content(response_content)
        if 'community_short_name' in response:
            self.community_short_name = response['community_short_name']
        if 'community_url' in response:
            self.community_url = response['community_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BsParticipantDTO import BsParticipantDTO


class AlipayCommerceOperationBsEnrollsRecoverModel(object):

    def __init__(self):
        self._participants = None
        self._plan_id = None

    @property
    def participants(self):
        return self._participants

    @participants.setter
    def participants(self, value):
        if isinstance(value, list):
            self._participants = list()
            for i in value:
                if isinstance(i, BsParticipantDTO):
                    self._participants.append(i)
                else:
                    self._participants.append(BsParticipantDTO.from_alipay_dict(i))
    @property
    def plan_id(self):
        return self._plan_id

    @plan_id.setter
    def plan_id(self, value):
        self._plan_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.participants:
            if isinstance(self.participants, list):
                for i in range(0, len(self.participants)):
                    element = self.participants[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.participants[i] = element.to_alipay_dict()
            if hasattr(self.participants, 'to_alipay_dict'):
                params['participants'] = self.participants.to_alipay_dict()
            else:
                params['participants'] = self.participants
        if self.plan_id:
            if hasattr(self.plan_id, 'to_alipay_dict'):
                params['plan_id'] = self.plan_id.to_alipay_dict()
            else:
                params['plan_id'] = self.plan_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationBsEnrollsRecoverModel()
        if 'participants' in d:
            o.participants = d['participants']
        if 'plan_id' in d:
            o.plan_id = d['plan_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsAgreementDTO import InsAgreementDTO
from alipay.aop.api.domain.InsurePlanDTO import InsurePlanDTO


class InsureRecommResultDTO(object):

    def __init__(self):
        self._agreement_list = None
        self._inst_id = None
        self._inst_logo = None
        self._inst_name = None
        self._inst_short_name = None
        self._insure_plans = None
        self._premium_payer_type = None
        self._prod_no = None
        self._product_code = None
        self._product_desc = None
        self._product_info_url = None
        self._product_name = None
        self._product_plan_id = None
        self._recommend_flow_id = None
        self._show_uninsured_option = None
        self._sp_no = None

    @property
    def agreement_list(self):
        return self._agreement_list

    @agreement_list.setter
    def agreement_list(self, value):
        if isinstance(value, list):
            self._agreement_list = list()
            for i in value:
                if isinstance(i, InsAgreementDTO):
                    self._agreement_list.append(i)
                else:
                    self._agreement_list.append(InsAgreementDTO.from_alipay_dict(i))
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def inst_logo(self):
        return self._inst_logo

    @inst_logo.setter
    def inst_logo(self, value):
        self._inst_logo = value
    @property
    def inst_name(self):
        return self._inst_name

    @inst_name.setter
    def inst_name(self, value):
        self._inst_name = value
    @property
    def inst_short_name(self):
        return self._inst_short_name

    @inst_short_name.setter
    def inst_short_name(self, value):
        self._inst_short_name = value
    @property
    def insure_plans(self):
        return self._insure_plans

    @insure_plans.setter
    def insure_plans(self, value):
        if isinstance(value, list):
            self._insure_plans = list()
            for i in value:
                if isinstance(i, InsurePlanDTO):
                    self._insure_plans.append(i)
                else:
                    self._insure_plans.append(InsurePlanDTO.from_alipay_dict(i))
    @property
    def premium_payer_type(self):
        return self._premium_payer_type

    @premium_payer_type.setter
    def premium_payer_type(self, value):
        self._premium_payer_type = value
    @property
    def prod_no(self):
        return self._prod_no

    @prod_no.setter
    def prod_no(self, value):
        self._prod_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def product_desc(self):
        return self._product_desc

    @product_desc.setter
    def product_desc(self, value):
        self._product_desc = value
    @property
    def product_info_url(self):
        return self._product_info_url

    @product_info_url.setter
    def product_info_url(self, value):
        self._product_info_url = value
    @property
    def product_name(self):
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        self._product_name = value
    @property
    def product_plan_id(self):
        return self._product_plan_id

    @product_plan_id.setter
    def product_plan_id(self, value):
        self._product_plan_id = value
    @property
    def recommend_flow_id(self):
        return self._recommend_flow_id

    @recommend_flow_id.setter
    def recommend_flow_id(self, value):
        self._recommend_flow_id = value
    @property
    def show_uninsured_option(self):
        return self._show_uninsured_option

    @show_uninsured_option.setter
    def show_uninsured_option(self, value):
        self._show_uninsured_option = value
    @property
    def sp_no(self):
        return self._sp_no

    @sp_no.setter
    def sp_no(self, value):
        self._sp_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_list:
            if isinstance(self.agreement_list, list):
                for i in range(0, len(self.agreement_list)):
                    element = self.agreement_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.agreement_list[i] = element.to_alipay_dict()
            if hasattr(self.agreement_list, 'to_alipay_dict'):
                params['agreement_list'] = self.agreement_list.to_alipay_dict()
            else:
                params['agreement_list'] = self.agreement_list
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.inst_logo:
            if hasattr(self.inst_logo, 'to_alipay_dict'):
                params['inst_logo'] = self.inst_logo.to_alipay_dict()
            else:
                params['inst_logo'] = self.inst_logo
        if self.inst_name:
            if hasattr(self.inst_name, 'to_alipay_dict'):
                params['inst_name'] = self.inst_name.to_alipay_dict()
            else:
                params['inst_name'] = self.inst_name
        if self.inst_short_name:
            if hasattr(self.inst_short_name, 'to_alipay_dict'):
                params['inst_short_name'] = self.inst_short_name.to_alipay_dict()
            else:
                params['inst_short_name'] = self.inst_short_name
        if self.insure_plans:
            if isinstance(self.insure_plans, list):
                for i in range(0, len(self.insure_plans)):
                    element = self.insure_plans[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.insure_plans[i] = element.to_alipay_dict()
            if hasattr(self.insure_plans, 'to_alipay_dict'):
                params['insure_plans'] = self.insure_plans.to_alipay_dict()
            else:
                params['insure_plans'] = self.insure_plans
        if self.premium_payer_type:
            if hasattr(self.premium_payer_type, 'to_alipay_dict'):
                params['premium_payer_type'] = self.premium_payer_type.to_alipay_dict()
            else:
                params['premium_payer_type'] = self.premium_payer_type
        if self.prod_no:
            if hasattr(self.prod_no, 'to_alipay_dict'):
                params['prod_no'] = self.prod_no.to_alipay_dict()
            else:
                params['prod_no'] = self.prod_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.product_desc:
            if hasattr(self.product_desc, 'to_alipay_dict'):
                params['product_desc'] = self.product_desc.to_alipay_dict()
            else:
                params['product_desc'] = self.product_desc
        if self.product_info_url:
            if hasattr(self.product_info_url, 'to_alipay_dict'):
                params['product_info_url'] = self.product_info_url.to_alipay_dict()
            else:
                params['product_info_url'] = self.product_info_url
        if self.product_name:
            if hasattr(self.product_name, 'to_alipay_dict'):
                params['product_name'] = self.product_name.to_alipay_dict()
            else:
                params['product_name'] = self.product_name
        if self.product_plan_id:
            if hasattr(self.product_plan_id, 'to_alipay_dict'):
                params['product_plan_id'] = self.product_plan_id.to_alipay_dict()
            else:
                params['product_plan_id'] = self.product_plan_id
        if self.recommend_flow_id:
            if hasattr(self.recommend_flow_id, 'to_alipay_dict'):
                params['recommend_flow_id'] = self.recommend_flow_id.to_alipay_dict()
            else:
                params['recommend_flow_id'] = self.recommend_flow_id
        if self.show_uninsured_option:
            if hasattr(self.show_uninsured_option, 'to_alipay_dict'):
                params['show_uninsured_option'] = self.show_uninsured_option.to_alipay_dict()
            else:
                params['show_uninsured_option'] = self.show_uninsured_option
        if self.sp_no:
            if hasattr(self.sp_no, 'to_alipay_dict'):
                params['sp_no'] = self.sp_no.to_alipay_dict()
            else:
                params['sp_no'] = self.sp_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsureRecommResultDTO()
        if 'agreement_list' in d:
            o.agreement_list = d['agreement_list']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'inst_logo' in d:
            o.inst_logo = d['inst_logo']
        if 'inst_name' in d:
            o.inst_name = d['inst_name']
        if 'inst_short_name' in d:
            o.inst_short_name = d['inst_short_name']
        if 'insure_plans' in d:
            o.insure_plans = d['insure_plans']
        if 'premium_payer_type' in d:
            o.premium_payer_type = d['premium_payer_type']
        if 'prod_no' in d:
            o.prod_no = d['prod_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'product_desc' in d:
            o.product_desc = d['product_desc']
        if 'product_info_url' in d:
            o.product_info_url = d['product_info_url']
        if 'product_name' in d:
            o.product_name = d['product_name']
        if 'product_plan_id' in d:
            o.product_plan_id = d['product_plan_id']
        if 'recommend_flow_id' in d:
            o.recommend_flow_id = d['recommend_flow_id']
        if 'show_uninsured_option' in d:
            o.show_uninsured_option = d['show_uninsured_option']
        if 'sp_no' in d:
            o.sp_no = d['sp_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantMemberwalletReturnSubmitResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantMemberwalletReturnSubmitResponse, self).__init__()
        self._actual_return_amount = None
        self._return_amount = None

    @property
    def actual_return_amount(self):
        return self._actual_return_amount

    @actual_return_amount.setter
    def actual_return_amount(self, value):
        self._actual_return_amount = value
    @property
    def return_amount(self):
        return self._return_amount

    @return_amount.setter
    def return_amount(self, value):
        self._return_amount = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantMemberwalletReturnSubmitResponse, self).parse_response_content(response_content)
        if 'actual_return_amount' in response:
            self.actual_return_amount = response['actual_return_amount']
        if 'return_amount' in response:
            self.return_amount = response['return_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsClaimAttachment(object):

    def __init__(self):
        self._description = None
        self._name = None
        self._path = None
        self._reason = None
        self._status = None
        self._type = None

    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, value):
        self._path = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.path:
            if hasattr(self.path, 'to_alipay_dict'):
                params['path'] = self.path.to_alipay_dict()
            else:
                params['path'] = self.path
        if self.reason:
            if hasattr(self.reason, 'to_alipay_dict'):
                params['reason'] = self.reason.to_alipay_dict()
            else:
                params['reason'] = self.reason
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsClaimAttachment()
        if 'description' in d:
            o.description = d['description']
        if 'name' in d:
            o.name = d['name']
        if 'path' in d:
            o.path = d['path']
        if 'reason' in d:
            o.reason = d['reason']
        if 'status' in d:
            o.status = d['status']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IssueRuleInfo import IssueRuleInfo
from alipay.aop.api.domain.StandardInfo import StandardInfo


class AlipayEbppInvoiceInstitutionCreateModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._consult_mode = None
        self._effective_end_date = None
        self._effective_start_date = None
        self._enterprise_id = None
        self._expense_type = None
        self._institution_desc = None
        self._institution_name = None
        self._issue_rule_info_list = None
        self._scene_type = None
        self._standard_info_list = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def consult_mode(self):
        return self._consult_mode

    @consult_mode.setter
    def consult_mode(self, value):
        self._consult_mode = value
    @property
    def effective_end_date(self):
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, value):
        self._effective_end_date = value
    @property
    def effective_start_date(self):
        return self._effective_start_date

    @effective_start_date.setter
    def effective_start_date(self, value):
        self._effective_start_date = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def expense_type(self):
        return self._expense_type

    @expense_type.setter
    def expense_type(self, value):
        self._expense_type = value
    @property
    def institution_desc(self):
        return self._institution_desc

    @institution_desc.setter
    def institution_desc(self, value):
        self._institution_desc = value
    @property
    def institution_name(self):
        return self._institution_name

    @institution_name.setter
    def institution_name(self, value):
        self._institution_name = value
    @property
    def issue_rule_info_list(self):
        return self._issue_rule_info_list

    @issue_rule_info_list.setter
    def issue_rule_info_list(self, value):
        if isinstance(value, list):
            self._issue_rule_info_list = list()
            for i in value:
                if isinstance(i, IssueRuleInfo):
                    self._issue_rule_info_list.append(i)
                else:
                    self._issue_rule_info_list.append(IssueRuleInfo.from_alipay_dict(i))
    @property
    def scene_type(self):
        return self._scene_type

    @scene_type.setter
    def scene_type(self, value):
        self._scene_type = value
    @property
    def standard_info_list(self):
        return self._standard_info_list

    @standard_info_list.setter
    def standard_info_list(self, value):
        if isinstance(value, list):
            self._standard_info_list = list()
            for i in value:
                if isinstance(i, StandardInfo):
                    self._standard_info_list.append(i)
                else:
                    self._standard_info_list.append(StandardInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.consult_mode:
            if hasattr(self.consult_mode, 'to_alipay_dict'):
                params['consult_mode'] = self.consult_mode.to_alipay_dict()
            else:
                params['consult_mode'] = self.consult_mode
        if self.effective_end_date:
            if hasattr(self.effective_end_date, 'to_alipay_dict'):
                params['effective_end_date'] = self.effective_end_date.to_alipay_dict()
            else:
                params['effective_end_date'] = self.effective_end_date
        if self.effective_start_date:
            if hasattr(self.effective_start_date, 'to_alipay_dict'):
                params['effective_start_date'] = self.effective_start_date.to_alipay_dict()
            else:
                params['effective_start_date'] = self.effective_start_date
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.expense_type:
            if hasattr(self.expense_type, 'to_alipay_dict'):
                params['expense_type'] = self.expense_type.to_alipay_dict()
            else:
                params['expense_type'] = self.expense_type
        if self.institution_desc:
            if hasattr(self.institution_desc, 'to_alipay_dict'):
                params['institution_desc'] = self.institution_desc.to_alipay_dict()
            else:
                params['institution_desc'] = self.institution_desc
        if self.institution_name:
            if hasattr(self.institution_name, 'to_alipay_dict'):
                params['institution_name'] = self.institution_name.to_alipay_dict()
            else:
                params['institution_name'] = self.institution_name
        if self.issue_rule_info_list:
            if isinstance(self.issue_rule_info_list, list):
                for i in range(0, len(self.issue_rule_info_list)):
                    element = self.issue_rule_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.issue_rule_info_list[i] = element.to_alipay_dict()
            if hasattr(self.issue_rule_info_list, 'to_alipay_dict'):
                params['issue_rule_info_list'] = self.issue_rule_info_list.to_alipay_dict()
            else:
                params['issue_rule_info_list'] = self.issue_rule_info_list
        if self.scene_type:
            if hasattr(self.scene_type, 'to_alipay_dict'):
                params['scene_type'] = self.scene_type.to_alipay_dict()
            else:
                params['scene_type'] = self.scene_type
        if self.standard_info_list:
            if isinstance(self.standard_info_list, list):
                for i in range(0, len(self.standard_info_list)):
                    element = self.standard_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.standard_info_list[i] = element.to_alipay_dict()
            if hasattr(self.standard_info_list, 'to_alipay_dict'):
                params['standard_info_list'] = self.standard_info_list.to_alipay_dict()
            else:
                params['standard_info_list'] = self.standard_info_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceInstitutionCreateModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'consult_mode' in d:
            o.consult_mode = d['consult_mode']
        if 'effective_end_date' in d:
            o.effective_end_date = d['effective_end_date']
        if 'effective_start_date' in d:
            o.effective_start_date = d['effective_start_date']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'expense_type' in d:
            o.expense_type = d['expense_type']
        if 'institution_desc' in d:
            o.institution_desc = d['institution_desc']
        if 'institution_name' in d:
            o.institution_name = d['institution_name']
        if 'issue_rule_info_list' in d:
            o.issue_rule_info_list = d['issue_rule_info_list']
        if 'scene_type' in d:
            o.scene_type = d['scene_type']
        if 'standard_info_list' in d:
            o.standard_info_list = d['standard_info_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GiftTemplateAtmosphereBox import GiftTemplateAtmosphereBox
from alipay.aop.api.domain.GiftTemplateBackCoverBox import GiftTemplateBackCoverBox
from alipay.aop.api.domain.GiftTemplateBaseInfo import GiftTemplateBaseInfo
from alipay.aop.api.domain.GiftTemplateButtonBox import GiftTemplateButtonBox
from alipay.aop.api.domain.GiftTemplateFrontCoverBox import GiftTemplateFrontCoverBox
from alipay.aop.api.domain.GiftTemplateStoryBox import GiftTemplateStoryBox


class GiftUserTemplateBoxInfo(object):

    def __init__(self):
        self._atmosphere_box = None
        self._back_cover_box = None
        self._base_info = None
        self._button_box = None
        self._front_cover_box = None
        self._story_box = None
        self._valid = None
        self._valid_end_time = None
        self._valid_start_time = None

    @property
    def atmosphere_box(self):
        return self._atmosphere_box

    @atmosphere_box.setter
    def atmosphere_box(self, value):
        if isinstance(value, GiftTemplateAtmosphereBox):
            self._atmosphere_box = value
        else:
            self._atmosphere_box = GiftTemplateAtmosphereBox.from_alipay_dict(value)
    @property
    def back_cover_box(self):
        return self._back_cover_box

    @back_cover_box.setter
    def back_cover_box(self, value):
        if isinstance(value, GiftTemplateBackCoverBox):
            self._back_cover_box = value
        else:
            self._back_cover_box = GiftTemplateBackCoverBox.from_alipay_dict(value)
    @property
    def base_info(self):
        return self._base_info

    @base_info.setter
    def base_info(self, value):
        if isinstance(value, GiftTemplateBaseInfo):
            self._base_info = value
        else:
            self._base_info = GiftTemplateBaseInfo.from_alipay_dict(value)
    @property
    def button_box(self):
        return self._button_box

    @button_box.setter
    def button_box(self, value):
        if isinstance(value, GiftTemplateButtonBox):
            self._button_box = value
        else:
            self._button_box = GiftTemplateButtonBox.from_alipay_dict(value)
    @property
    def front_cover_box(self):
        return self._front_cover_box

    @front_cover_box.setter
    def front_cover_box(self, value):
        if isinstance(value, GiftTemplateFrontCoverBox):
            self._front_cover_box = value
        else:
            self._front_cover_box = GiftTemplateFrontCoverBox.from_alipay_dict(value)
    @property
    def story_box(self):
        return self._story_box

    @story_box.setter
    def story_box(self, value):
        if isinstance(value, GiftTemplateStoryBox):
            self._story_box = value
        else:
            self._story_box = GiftTemplateStoryBox.from_alipay_dict(value)
    @property
    def valid(self):
        return self._valid

    @valid.setter
    def valid(self, value):
        self._valid = value
    @property
    def valid_end_time(self):
        return self._valid_end_time

    @valid_end_time.setter
    def valid_end_time(self, value):
        self._valid_end_time = value
    @property
    def valid_start_time(self):
        return self._valid_start_time

    @valid_start_time.setter
    def valid_start_time(self, value):
        self._valid_start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.atmosphere_box:
            if hasattr(self.atmosphere_box, 'to_alipay_dict'):
                params['atmosphere_box'] = self.atmosphere_box.to_alipay_dict()
            else:
                params['atmosphere_box'] = self.atmosphere_box
        if self.back_cover_box:
            if hasattr(self.back_cover_box, 'to_alipay_dict'):
                params['back_cover_box'] = self.back_cover_box.to_alipay_dict()
            else:
                params['back_cover_box'] = self.back_cover_box
        if self.base_info:
            if hasattr(self.base_info, 'to_alipay_dict'):
                params['base_info'] = self.base_info.to_alipay_dict()
            else:
                params['base_info'] = self.base_info
        if self.button_box:
            if hasattr(self.button_box, 'to_alipay_dict'):
                params['button_box'] = self.button_box.to_alipay_dict()
            else:
                params['button_box'] = self.button_box
        if self.front_cover_box:
            if hasattr(self.front_cover_box, 'to_alipay_dict'):
                params['front_cover_box'] = self.front_cover_box.to_alipay_dict()
            else:
                params['front_cover_box'] = self.front_cover_box
        if self.story_box:
            if hasattr(self.story_box, 'to_alipay_dict'):
                params['story_box'] = self.story_box.to_alipay_dict()
            else:
                params['story_box'] = self.story_box
        if self.valid:
            if hasattr(self.valid, 'to_alipay_dict'):
                params['valid'] = self.valid.to_alipay_dict()
            else:
                params['valid'] = self.valid
        if self.valid_end_time:
            if hasattr(self.valid_end_time, 'to_alipay_dict'):
                params['valid_end_time'] = self.valid_end_time.to_alipay_dict()
            else:
                params['valid_end_time'] = self.valid_end_time
        if self.valid_start_time:
            if hasattr(self.valid_start_time, 'to_alipay_dict'):
                params['valid_start_time'] = self.valid_start_time.to_alipay_dict()
            else:
                params['valid_start_time'] = self.valid_start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GiftUserTemplateBoxInfo()
        if 'atmosphere_box' in d:
            o.atmosphere_box = d['atmosphere_box']
        if 'back_cover_box' in d:
            o.back_cover_box = d['back_cover_box']
        if 'base_info' in d:
            o.base_info = d['base_info']
        if 'button_box' in d:
            o.button_box = d['button_box']
        if 'front_cover_box' in d:
            o.front_cover_box = d['front_cover_box']
        if 'story_box' in d:
            o.story_box = d['story_box']
        if 'valid' in d:
            o.valid = d['valid']
        if 'valid_end_time' in d:
            o.valid_end_time = d['valid_end_time']
        if 'valid_start_time' in d:
            o.valid_start_time = d['valid_start_time']
        return o


